@@ -22,6 +22,7 @@
 #include "collectionattributespage.h"
 #include "collectioninternalspage.h"
 #include "collectionaclpage.h"
+#include "dbaccess.h"
 #include "settings.h"
 #include "akonadibrowsermodel.h"
 
@@ -41,14 +42,15 @@
 #include <akonadi/standardactionmanager.h>
 #include <akonadi/entitylistview.h>
 #include <akonadi/entitytreeview.h>
-#include <akonadi/entitytreeviewstatesaver.h>
+#include <akonadi/etmviewstatesaver.h>
 #include <akonadi/favoritecollectionsmodel.h>
 #include <akonadi_next/quotacolorproxymodel.h>
-#include <akonadi/statisticsproxymodel.h>
+#include <libkdepim/statisticsproxymodel.h>
+#include <kviewstatemaintainer.h>
 
 #include <kabc/addressee.h>
 #include <kabc/contactgroup.h>
-#include <kcal/incidence.h>
+#include <kcalcore/incidence.h>
 
 #include <kdebug.h>
 #include <kconfig.h>
@@ -57,11 +59,9 @@
 #include <kmessagebox.h>
 #include <kxmlguiwindow.h>
 
-#ifdef NEPOMUK_FOUND
 #include <nepomuk/resource.h>
 #include <nepomuk/resourcemanager.h>
 #include <nepomuk/variant.h>
-#endif
 
 #include <QSplitter>
 #include <QTextEdit>
@@ -69,12 +69,11 @@
 #include <QStackedWidget>
 #include <QtGui/QSortFilterProxyModel>
 #include <QStandardItemModel>
+#include <QSqlError>
+#include <QSqlQuery>
 #include <QTimer>
 
-#include <akonadi_next/modeltest.h>
-
 using namespace Akonadi;
-using namespace AkonadiFuture;
 
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionAttributePageFactory, CollectionAttributePage)
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionInternalsPageFactory, CollectionInternalsPage)
@@ -85,9 +84,7 @@ Q_DECLARE_METATYPE( QSet<QByteArray> )
 BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
     QWidget( parent ),
     mAttrModel( 0 ),
-#ifdef NEPOMUK_FOUND
     mNepomukModel( 0 ),
-#endif
     mStdActionManager( 0 ),
     mMonitor( 0 )
 {
@@ -136,7 +133,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
   collectionFilter->setDynamicSortFilter( true );
   collectionFilter->setSortCaseSensitivity( Qt::CaseInsensitive );
 
-  statisticsProxyModel = new StatisticsProxyModel( this );
+  statisticsProxyModel = new KPIM::StatisticsProxyModel( this );
   statisticsProxyModel->setToolTipEnabled( true );
   statisticsProxyModel->setSourceModel( collectionFilter );
 
@@ -150,10 +147,6 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
   selectionProxyModel->setSourceModel( mBrowserModel );
   selectionProxyModel->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
 
-  connect( selectionProxyModel, SIGNAL(modelAboutToBeReset()), SLOT(slotBrowserModelAboutToBeReset()) );
-  // Use a Queued connection here so that all proxies get a chance to process the reset before trying to restore the state.
-  connect( selectionProxyModel, SIGNAL(modelReset()), SLOT(slotBrowserModelReset()), Qt::QueuedConnection );
-
   EntityMimeTypeFilterModel *itemFilter = new EntityMimeTypeFilterModel( this );
   itemFilter->setSourceModel( selectionProxyModel );
   itemFilter->addMimeTypeExclusionFilter( Collection::mimeType() );
@@ -180,13 +173,14 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
   itemUi.itemView->setXmlGuiClient( xmlGuiWindow );
   itemUi.itemView->setModel( itemFilter );
   itemUi.itemView->setSelectionMode( QAbstractItemView::ExtendedSelection );
-  connect( itemUi.itemView, SIGNAL( activated( QModelIndex ) ), SLOT(itemActivated( QModelIndex ) ) );
-  connect( itemUi.itemView, SIGNAL( clicked( QModelIndex ) ), SLOT(itemActivated( QModelIndex ) ) );
+  connect( itemUi.itemView, SIGNAL(activated(QModelIndex)), SLOT(itemActivated(QModelIndex)) );
+  connect( itemUi.itemView, SIGNAL(clicked(QModelIndex)), SLOT(itemActivated(QModelIndex)) );
   splitter3->addWidget( itemViewParent );
   itemViewParent->layout()->setMargin( 0 );
 
   QWidget *contentViewParent = new QWidget( this );
   contentUi.setupUi( contentViewParent );
+  contentUi.saveButton->setEnabled( false );
   connect( contentUi.saveButton, SIGNAL(clicked()), SLOT(save()) );
   splitter3->addWidget( contentViewParent );
 
@@ -206,23 +200,17 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
   mStdActionManager->setFavoriteSelectionModel( favoritesView->selectionModel() );
   mStdActionManager->createAllActions();
 
-#ifndef NEPOMUK_FOUND
-  contentUi.mainTabWidget->removeTab( contentUi.mainTabWidget->indexOf( contentUi.nepomukTab ) );
-#else
   Nepomuk::ResourceManager::instance()->init();
-#endif
 
-  const KConfigGroup cfg( KGlobal::config(), "CollectionViewState" );
-  EntityTreeViewStateSaver* saver = new EntityTreeViewStateSaver( mCollectionView );
-  saver->restoreState( cfg );
+  m_stateMaintainer = new KViewStateMaintainer<ETMViewStateSaver>( KGlobal::config()->group("CollectionViewState"), this );
+  m_stateMaintainer->setView( mCollectionView );
+
+  m_stateMaintainer->restoreState();
 }
 
 BrowserWidget::~BrowserWidget()
 {
-  KConfigGroup cfg( KGlobal::config(), "CollectionViewState" );
-  EntityTreeViewStateSaver saver( mCollectionView );
-  saver.saveState( cfg );
-  cfg.sync();
+  m_stateMaintainer->saveState();
 }
 
 void BrowserWidget::clear()
@@ -250,7 +238,7 @@ void BrowserWidget::itemActivated(const QModelIndex & index)
   ItemFetchJob *job = new ItemFetchJob( item, this );
   job->fetchScope().fetchFullPayload();
   job->fetchScope().fetchAllAttributes();
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( itemFetchDone( KJob* ) ), Qt::QueuedConnection );
+  connect( job, SIGNAL(result(KJob*)), SLOT(itemFetchDone(KJob*)), Qt::QueuedConnection );
 }
 
 void BrowserWidget::itemFetchDone(KJob * job)
@@ -275,9 +263,13 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
   } else if ( item.hasPayload<KABC::ContactGroup>() ) {
     contentUi.contactGroupView->setItem( item );
     contentUi.stack->setCurrentWidget( contentUi.contactGroupViewPage );
-  } else if ( item.hasPayload<KCal::Incidence::Ptr>() ) {
+  } else if ( item.hasPayload<KCalCore::Incidence::Ptr>() ) {
     contentUi.incidenceView->setItem( item );
     contentUi.stack->setCurrentWidget( contentUi.incidenceViewPage );
+  } else if ( item.mimeType() == "message/rfc822"
+              || item.mimeType() == "message/news" ) {
+    contentUi.mailView->setMessageItem( item, MessageViewer::Viewer::Force );
+    contentUi.stack->setCurrentWidget( contentUi.mailViewPage );
   } else if ( item.hasPayload<QPixmap>() ) {
     contentUi.imageView->setPixmap( item.payload<QPixmap>() );
     contentUi.stack->setCurrentWidget( contentUi.imageViewPage );
@@ -300,6 +292,7 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
   contentUi.flags->setItems( flags );
 
   Attribute::List list = item.attributes();
+  delete mAttrModel;
   mAttrModel = new QStandardItemModel( list.count(), 2 );
   QStringList labels;
   labels << i18n( "Attribute" ) << i18n( "Value" );
@@ -315,7 +308,6 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
   }
   contentUi.attrView->setModel( mAttrModel );
 
-#ifdef NEPOMUK_FOUND
   if ( Settings::self()->nepomukEnabled() ) {
     Nepomuk::Resource res( item.url() );
 
@@ -349,7 +341,6 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
   } else {
     contentUi.nepomukTab->setEnabled( false );
   }
-#endif
 
   if ( mMonitor )
     mMonitor->deleteLater(); // might be the one calling us
@@ -406,12 +397,10 @@ void BrowserWidget::save()
   ItemModifyJob *store = new ItemModifyJob( item, this );
   connect( store, SIGNAL(result(KJob*)), SLOT(saveResult(KJob*)) );
 
-#ifdef NEPOMUK_FOUND
   if ( Settings::self()->nepomukEnabled() ) {
     Nepomuk::Resource res( item.url() );
     res.setRating( contentUi.ratingWidget->rating() );
   }
-#endif
 }
 
 void BrowserWidget::saveResult(KJob * job)
@@ -423,7 +412,7 @@ void BrowserWidget::saveResult(KJob * job)
 
 void BrowserWidget::addAttribute()
 {
-  if ( contentUi.attrName->text().isEmpty() )
+  if ( !mAttrModel || contentUi.attrName->text().isEmpty() )
     return;
   const int row = mAttrModel->rowCount();
   mAttrModel->insertRow( row );
@@ -431,19 +420,25 @@ void BrowserWidget::addAttribute()
   Q_ASSERT( index.isValid() );
   mAttrModel->setData( index, contentUi.attrName->text() );
   contentUi.attrName->clear();
+  contentUi.saveButton->setEnabled( true );
 }
 
 void BrowserWidget::delAttribute()
 {
+  if ( !mAttrModel )
+    return;
   QModelIndexList selection = contentUi.attrView->selectionModel()->selectedRows();
   if ( selection.count() != 1 )
     return;
   mAttrModel->removeRow( selection.first().row() );
+  if ( mAttrModel->rowCount() == 0 ) {
+    contentUi.saveButton->setEnabled( false );
+  }
 }
 
 void BrowserWidget::dumpToXml()
 {
-  const Collection root = mCollectionView->currentIndex().data( EntityTreeModel::CollectionRole ).value<Collection>();
+  const Collection root = currentCollection();
   if ( !root.isValid() )
     return;
   const QString fileName = KFileDialog::getSaveFileName( KUrl(), "*.xml", this, i18n( "Select XML file" ) );
@@ -461,20 +456,24 @@ void BrowserWidget::dumpToXmlResult( KJob* job )
     KMessageBox::error( this, job->errorString() );
 }
 
-void BrowserWidget::slotBrowserModelAboutToBeReset()
+void BrowserWidget::clearCache()
 {
-  KConfigGroup cfg( KGlobal::config(), "CollectionViewState" );
-  EntityTreeViewStateSaver saver( mCollectionView );
-  saver.saveState( cfg );
-  cfg.sync();
+  const Collection coll = currentCollection();
+  if ( !coll.isValid() )
+    return;
+  QString str = QString("DELETE FROM pimitemtable WHERE collectionId=%1").arg(coll.id());
+  qDebug() << str;
+  QSqlQuery query( str, DbAccess::database() );
+  query.exec();
+  if (query.lastError().isValid()) {
+     qDebug() << query.lastError();
+     KMessageBox::error( this, query.lastError().text() );
+   }
 }
 
-void BrowserWidget::slotBrowserModelReset()
+Akonadi::Collection BrowserWidget::currentCollection() const
 {
-  const KConfigGroup cfg( KGlobal::config(), "CollectionViewState" );
-  EntityTreeViewStateSaver* saver = new EntityTreeViewStateSaver( mCollectionView );
-  saver->restoreState( cfg );
+  return mCollectionView->currentIndex().data( EntityTreeModel::CollectionRole ).value<Collection>();
 }
 
-
 #include "browserwidget.moc"
