@@ -210,13 +210,6 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenHomepage()));
     action->setShortcuts(KShortcut( "Ctrl+H" ));
 
-    action = coll->addAction("reload_all_tabs");
-    action->setIcon(KIcon("view-refresh"));
-    action->setText(i18n("Reload All Tabs"));
-    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotReloadAllTabs()));
-    action->setShortcuts(KShortcut( "Shift+F5" ));
-
-
     action = coll->addAction("feed_add");
     action->setIcon(KIcon("feed-subscribe"));
     action->setText(i18n("&Add Feed..."));
@@ -304,12 +297,6 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticles()));
     action->setShortcuts(KShortcut( "Shift+Return" ));
 
-    action = coll->addAction("article_open_in_background" );
-    action->setIcon(KIcon("tab-new"));
-    action->setText(i18n("Open in Background Tab"));
-    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticlesInBackground()));
-    action->setShortcuts(KShortcut( "Return" ));
-
     action = coll->addAction("article_open_external" );
     action->setIcon(KIcon("window-new"));
     action->setText(i18n("Open in External Browser"));
@@ -569,17 +556,6 @@ void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
     action->setText(i18n("Shrink Font"));
     connect(action, SIGNAL(triggered(bool)), d->tabWidget, SLOT(slotFrameZoomOut()));
     action->setShortcut( QKeySequence::ZoomOut );
-
-    QString actionname;
-    for (int i=1;i<10;++i) {
-      actionname.sprintf("activate_tab_%02d", i);
-      action = new KAction( i18n("Activate Tab %1", i),this );
-      action->setShortcut( QKeySequence( QString::fromLatin1( "Alt+%1" ).arg( i ) ) );
-      coll->addAction( actionname, action );
-      connect( action, SIGNAL(triggered(bool)), d->tabWidget, SLOT(slotActivateTab()) );
-    }
-
-
 }
 
 void ActionManagerImpl::initFrameManager(FrameManager* frameManager)
@@ -588,7 +564,7 @@ void ActionManagerImpl::initFrameManager(FrameManager* frameManager)
         return;
 
     d->frameManager = frameManager;
-
+    
     bool isRTL = QApplication::isRightToLeft();
 
     KToolBarPopupAction* forward = new KToolBarPopupAction(KIcon(isRTL ? "go-previous" : "go-next"), i18nc("Go forward in browser history", "Forward"), this);
@@ -618,11 +594,7 @@ void ActionManagerImpl::initFrameManager(FrameManager* frameManager)
 
 QWidget* ActionManagerImpl::container(const char* name)
 {
-    if ( d->part->factory() ) {
-        return d->part->factory()->container(name, d->part);
-    } else {
-        return 0;
-    }
+    return d->part->factory()->container(name, d->part);
 }
 
 
@@ -646,9 +618,9 @@ void ActionManagerImpl::setArticleActionsEnabled( bool enabled ) {
     setActionEnabled("article_delete")
     setActionEnabled("file_sendlink")
     setActionEnabled("file_sendfile")
-    setActionEnabled("article_open_in_background")
 #undef setActionEnabled
 }
 
 } // namespace Akregator
 
+#include "actionmanagerimpl.moc"
