@@ -1,7 +1,7 @@
 /*
  *  functions.h  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright © 2004-2010 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2012 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,15 +23,25 @@
 
 /**  @file functions.h - miscellaneous functions */
 
-#include <QSize>
-#include <QString>
-#include <QList>
-
 #include "editdlg.h"
-#include "kaevent.h"
+#ifdef USE_AKONADI
+#include "eventid.h"
+#endif
+
+#include <kalarmcal/kaevent.h>
+#ifdef USE_AKONADI
+#include <akonadi/collection.h>
+#include <akonadi/item.h>
+#endif
 #include <kfile.h>
 #include <kmimetype.h>
 
+#include <QSize>
+#include <QString>
+#include <QVector>
+
+using namespace KAlarmCal;
+
 namespace KCal { class Event; }
 class QWidget;
 class QAction;
@@ -39,9 +49,7 @@ class KAction;
 class KActionCollection;
 class KToggleAction;
 class AlarmResource;
-class KAEvent;
 class MainWindow;
-class AlarmText;
 class TemplateMenuAction;
 
 namespace KAlarm
@@ -54,20 +62,24 @@ enum FileType { Unknown, TextPlain, TextFormatted, TextApplication, Image };
  *  DO NOT CHANGE THE ORDER OF THESE VALUES!
  */
 enum UpdateStatus {
-	UPDATE_OK,            // update succeeded
-	UPDATE_KORG_FUNCERR,  // update succeeded, but KOrganizer reported an error updating
-	UPDATE_KORG_ERRSTART, // update succeeded, but KOrganizer update failed (KOrganizer not fully started)
-	UPDATE_KORG_ERR,      // update succeeded, but KOrganizer update failed
-	UPDATE_ERROR,         // update failed partially
-	UPDATE_FAILED,        // update failed completely
-	SAVE_FAILED           // calendar was updated in memory, but save failed
+    UPDATE_OK,            // update succeeded
+    UPDATE_KORG_FUNCERR,  // update succeeded, but KOrganizer reported an error updating
+    UPDATE_KORG_ERRSTART, // update succeeded, but KOrganizer update failed (KOrganizer not fully started)
+    UPDATE_KORG_ERR,      // update succeeded, but KOrganizer update failed
+    UPDATE_ERROR,         // update failed partially
+    UPDATE_FAILED,        // update failed completely
+    SAVE_FAILED           // calendar was updated in memory, but save failed
 };
 /** Error codes supplied as parameter to displayUpdateError() */
 enum UpdateError { ERR_ADD, ERR_MODIFY, ERR_DELETE, ERR_REACTIVATE, ERR_TEMPLATE };
 
 
 /** Display a main window with the specified event selected */
-MainWindow*         displayMainWindowSelected(const QString& eventID = QString());
+#ifdef USE_AKONADI
+MainWindow*         displayMainWindowSelected(Akonadi::Item::Id = -1);
+#else
+MainWindow*         displayMainWindowSelected(const QString& eventId = QString());
+#endif
 bool                readConfigWindowSize(const char* window, QSize&, int* splitterWidth = 0);
 void                writeConfigWindowSize(const char* window, const QSize&, int splitterWidth = -1);
 /** Check from its mime type whether a file appears to be a text or image file.
@@ -78,11 +90,11 @@ FileType            fileType(const KMimeType::Ptr& mimetype);
  *  Display a Continue/Cancel error message if 'errmsgParent' non-null.
  */
 enum FileErr {
-	FileErr_None = 0,
-	FileErr_Blank,           // generic blank error
-	FileErr_Nonexistent, FileErr_Directory, FileErr_Unreadable, FileErr_NotTextImage,
-	FileErr_BlankDisplay,    // blank error to use for file to display
-	FileErr_BlankPlay        // blank error to use for file to play
+    FileErr_None = 0,
+    FileErr_Blank,           // generic blank error
+    FileErr_Nonexistent, FileErr_Directory, FileErr_Unreadable, FileErr_NotTextImage,
+    FileErr_BlankDisplay,    // blank error to use for file to display
+    FileErr_BlankPlay        // blank error to use for file to play
 };
 FileErr             checkFileExists(QString& filename, KUrl&);
 bool                showFileErrMessage(const QString& filename, FileErr, FileErr blankError, QWidget* errmsgParent);
@@ -94,18 +106,21 @@ QString             browseFile(const QString& caption, QString& defaultDir, cons
                                const QString& filter = QString(), KFile::Modes mode = 0, QWidget* parent = 0);
 bool                editNewAlarm(const QString& templateName, QWidget* parent = 0);
 void                editNewAlarm(EditAlarmDlg::Type, QWidget* parent = 0);
-void                editNewAlarm(KAEventData::Action, QWidget* parent = 0, const AlarmText* = 0);
+void                editNewAlarm(KAEvent::SubAction, QWidget* parent = 0, const AlarmText* = 0);
 void                editNewAlarm(const KAEvent* preset, QWidget* parent = 0);
-bool                editAlarm(const QString& eventID, QWidget* parent = 0);
+bool                editAlarmById(const QString& eventID, QWidget* parent = 0);
 void                editAlarm(KAEvent*, QWidget* parent = 0);
+#ifdef USE_AKONADI
+void                updateEditedAlarm(EditAlarmDlg*, KAEvent&, Akonadi::Collection&);
+#else
 void                updateEditedAlarm(EditAlarmDlg*, KAEvent&, AlarmResource*);
+#endif
 void                viewAlarm(const KAEvent*, QWidget* parent = 0);
 void                editNewTemplate(EditAlarmDlg::Type, QWidget* parent = 0);
 void                editNewTemplate(const KAEvent* preset, QWidget* parent = 0);
 void                editTemplate(KAEvent*, QWidget* parent = 0);
-void                execNewAlarmDlg(EditAlarmDlg*, bool alreadyExecuted = false);
+void                execNewAlarmDlg(EditAlarmDlg*);
 /** Create a "New From Template" QAction */
-TemplateMenuAction* createNewFromTemplateAction(const QString& label, KActionCollection*, const QString& name);
 KToggleAction*      createAlarmEnableAction(QObject* parent);
 KAction*            createStopPlayAction(QObject* parent);
 KToggleAction*      createSpreadWindowsAction(QObject* parent);
@@ -118,41 +133,84 @@ void                refreshAlarms();
 void                refreshAlarmsIfQueued();    // must only be called from KAlarmApp::processQueue()
 QString             runKMail(bool minimise);
 
+#ifdef USE_AKONADI
+QStringList         dontShowErrors(const EventId&);
+bool                dontShowErrors(const EventId&, const QString& tag);
+void                setDontShowErrors(const EventId&, const QStringList& tags = QStringList());
+void                setDontShowErrors(const EventId&, const QString& tag);
+#else
 QStringList         dontShowErrors(const QString& eventId);
 bool                dontShowErrors(const QString& eventId, const QString& tag);
 void                setDontShowErrors(const QString& eventId, const QStringList& tags = QStringList());
+#endif
 void                setDontShowErrors(const QString& eventId, const QString& tag);
 
 enum         // 'options' parameter values for addEvent(). May be OR'ed together.
 {
-	USE_EVENT_ID       = 0x01,   // use event ID if it's provided
-	NO_RESOURCE_PROMPT = 0x02,   // don't prompt for resource
-	ALLOW_KORG_UPDATE  = 0x04    // allow change to be sent to KOrganizer
+    USE_EVENT_ID       = 0x01,   // use event ID if it's provided
+    NO_RESOURCE_PROMPT = 0x02,   // don't prompt for resource
+    ALLOW_KORG_UPDATE  = 0x04    // allow change to be sent to KOrganizer
 };
+#ifdef USE_AKONADI
+UpdateStatus        addEvent(KAEvent&, Akonadi::Collection* = 0, QWidget* msgParent = 0, int options = ALLOW_KORG_UPDATE, bool showKOrgErr = true);
+#else
 UpdateStatus        addEvent(KAEvent&, AlarmResource* = 0, QWidget* msgParent = 0, int options = ALLOW_KORG_UPDATE, bool showKOrgErr = true);
-UpdateStatus        addEvents(QList<KAEvent>&, QWidget* msgParent = 0, bool allowKOrgUpdate = true, bool showKOrgErr = true);
+#endif
+UpdateStatus        addEvents(QVector<KAEvent>&, QWidget* msgParent = 0, bool allowKOrgUpdate = true, bool showKOrgErr = true);
+#ifdef USE_AKONADI
+bool                addArchivedEvent(KAEvent&, Akonadi::Collection* = 0);
+UpdateStatus        addTemplate(KAEvent&, Akonadi::Collection* = 0, QWidget* msgParent = 0);
+#else
 bool                addArchivedEvent(KAEvent&, AlarmResource* = 0);
 UpdateStatus        addTemplate(KAEvent&, AlarmResource* = 0, QWidget* msgParent = 0);
+#endif
 UpdateStatus        modifyEvent(KAEvent& oldEvent, KAEvent& newEvent, QWidget* msgParent = 0, bool showKOrgErr = true);
 UpdateStatus        updateEvent(KAEvent&, QWidget* msgParent = 0, bool archiveOnDelete = true);
 UpdateStatus        updateTemplate(KAEvent&, QWidget* msgParent = 0);
 UpdateStatus        deleteEvent(KAEvent&, bool archive = true, QWidget* msgParent = 0, bool showKOrgErr = true);
+#ifdef USE_AKONADI
+UpdateStatus        deleteEvents(QVector<KAEvent>&, bool archive = true, QWidget* msgParent = 0, bool showKOrgErr = true);
+UpdateStatus        deleteTemplates(const KAEvent::List& events, QWidget* msgParent = 0);
+inline UpdateStatus deleteTemplate(KAEvent& event, QWidget* msgParent = 0)
+                        { KAEvent::List e;  e += &event;  return deleteTemplates(e, msgParent); }
+#else
 UpdateStatus        deleteEvents(KAEvent::List&, bool archive = true, QWidget* msgParent = 0, bool showKOrgErr = true);
 UpdateStatus        deleteTemplates(const QStringList& eventIDs, QWidget* msgParent = 0);
 inline UpdateStatus deleteTemplate(const QString& eventID, QWidget* msgParent = 0)
-			{ return deleteTemplates(QStringList(eventID), msgParent); }
+                        { return deleteTemplates(QStringList(eventID), msgParent); }
+#endif
 void                deleteDisplayEvent(const QString& eventID);
+#ifdef USE_AKONADI
+UpdateStatus        reactivateEvent(KAEvent&, Akonadi::Collection* = 0, QWidget* msgParent = 0, bool showKOrgErr = true);
+UpdateStatus        reactivateEvents(QVector<KAEvent>&, QVector<EventId>& ineligibleIDs, Akonadi::Collection* = 0, QWidget* msgParent = 0, bool showKOrgErr = true);
+UpdateStatus        enableEvents(QVector<KAEvent>&, bool enable, QWidget* msgParent = 0);
+#else
 UpdateStatus        reactivateEvent(KAEvent&, AlarmResource* = 0, QWidget* msgParent = 0, bool showKOrgErr = true);
 UpdateStatus        reactivateEvents(KAEvent::List&, QStringList& ineligibleIDs, AlarmResource* = 0, QWidget* msgParent = 0, bool showKOrgErr = true);
 UpdateStatus        enableEvents(KAEvent::List&, bool enable, QWidget* msgParent = 0);
+#endif
 void                purgeArchive(int purgeDays);    // must only be called from KAlarmApp::processQueue()
 void                displayUpdateError(QWidget* parent, UpdateStatus, UpdateError, int nAlarms, int nKOrgAlarms = 1, bool showKOrgError = true);
 void                displayKOrgUpdateError(QWidget* parent, UpdateError, UpdateStatus korgError, int nAlarms);
+QStringList         checkRtcWakeConfig(bool checkEventExists = false);
+void                deleteRtcWakeConfig();
+void                cancelRtcWake(QWidget* msgParent, const QString& eventId = QString());
+bool                setRtcWakeTime(unsigned triggerTime, QWidget* parent);
 
 bool                convertTimeString(const QByteArray& timeString, KDateTime& dateTime, const KDateTime& defaultDt = KDateTime(), bool allowTZ = true);
 KDateTime           applyTimeZone(const QString& tzstring, const QDate& date, const QTime& time,
                                   bool haveTime, const KDateTime& defaultDt = KDateTime());
-bool                isWorkingTime(const KDateTime&, const KAEventData*);
+
+/** Return a prompt string to ask the user whether to convert the calendar to the
+ *  current format.
+ *  @param whole if true, the whole calendar needs to be converted; else only some
+ *               alarms may need to be converted.
+ */
+QString             conversionPrompt(const QString& calendarName, const QString& calendarVersion, bool whole);
+
+#ifdef USE_AKONADI
+Akonadi::Collection invalidCollection();  // for use as a non-const default parameter
+#endif
 
 #ifndef NDEBUG
 void                setTestModeConditions();
@@ -164,3 +222,5 @@ void                setSimulatedSystemTime(const KDateTime&);
 bool caseInsensitiveLessThan(const QString& s1, const QString& s2);
 
 #endif // FUNCTIONS_H
+
+// vim: et sw=4:
