@@ -25,62 +25,64 @@
 #include "kmreaderwin.h" //for inline actions
 #include "kmkernel.h" // for access to config
 
+#include "foldertreewidget.h"
+
 #include <kurl.h>
 #include <kxmlguiclient.h>
 #include "messageactions.h"
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <kvbox.h>
+#include <foldercollection.h>
 
 #include <QList>
-#include <QVBoxLayout>
-#include <QMenu>
-#include <QHash>
+#include <QLabel>
 #include <QPointer>
+#include <QTimer>
+#include <akonadi/kmime/standardmailactionmanager.h>
+#include <messagelist/core/view.h>
+#include <Solid/Networking>
+
+namespace Akonadi {
+  class EntityListView;
+}
+
+namespace KMime {
+  class Message;
+}
 
 class QVBoxLayout;
 class QSplitter;
-class QSignalMapper;
 
+class QMenu;
 class KActionMenu;
-class KConfig;
 class KToggleAction;
-class KTreeWidgetSearchLine;
-
-class KMFolder;
 class KMMetaFilterActionCommand;
-class FolderShortcutCommand;
-class KMMessage;
-class KMFolder;
 class KMSystemTray;
-class KMMessageTagDescription;
-typedef QPair<KMMessageTagDescription*,KAction*> MessageTagPtrPair;
-class CustomTemplatesMenu;
+class CollectionPane;
+class KMCommand;
+class KMMoveCommand;
 
-
-template <typename T> class QList;
 template <typename T, typename S> class QMap;
-template <typename T> class QPointer;
 
 namespace KIO {
   class Job;
 }
 
 namespace KMail {
-  class Vacation;
-  class SieveDebugDialog;
-  class FolderJob;
   class SearchWindow;
-  class ImapAccountBase;
-  class FavoriteFolderView;
   class StatusBarLabel;
-  class MainFolderView;
-  class FolderViewManager;
-  namespace MessageListView
-  {
-    class MessageSet;
-    class Pane;
-  }
+  class TagActionManager;
+  class FolderShortcutActionManager;
+}
+
+namespace KSieveUi {
+  class SieveDebugDialog;
+  class Vacation;
+}
+
+namespace MailCommon {
+  class FolderSelectionDialog;
+  class FavoriteCollectionWidget;
 }
 
 class KMAIL_EXPORT KMMainWidget : public QWidget
@@ -100,7 +102,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
 
     KMMainWidget(QWidget *parent, KXMLGUIClient *aGUIClient,
                  KActionCollection *actionCollection,
-                 KSharedConfig::Ptr config = KMKernel::config() );
+                 KSharedConfig::Ptr config = KMKernel::self()->config() );
     virtual ~KMMainWidget();
     void destruct();
 
@@ -117,32 +119,22 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     virtual void readConfig();
 
     /** Write configuration options. */
-    virtual void writeConfig();
+    virtual void writeConfig(bool force = true);
+
+    void writeReaderConfig();
 
     /** Easy access to main components of the window. */
     KMReaderWin* messageView() const { return mMsgView; }
+    /** Access to the header list pane. */
+    CollectionPane* messageListPane() const { return mMessagePane; }
 
-    KMail::MainFolderView * mainFolderView() const
-      { return mMainFolderView; }
-    KMail::FavoriteFolderView * favoriteFolderView() const
-      { return mFavoriteFolderView; }
-    KMail::FolderViewManager * folderViewManager() const
-      { return mFolderViewManager; }
-    KMail::MessageListView::Pane * messageListView() const
-      { return mMessageListView; }
-    /**
-     * Returns the currently selected folder in messageListView().
-     */
-    KMFolder * folder() const;
-
+    QSharedPointer<MailCommon::FolderCollection> currentFolder() const;
 
     static void cleanup();
 
     QAction *action( const char *name ) { return mActionCollection->action( name ); }
     KActionMenu *filterMenu() const { return mFilterMenu; }
     KActionMenu *mailingListActionMenu() const { return mMsgActions->mailingListActionMenu(); }
-    KAction *printAction() const { return mPrintAction; }
-    KAction *trashAction() const { return mTrashAction; }
     KAction *deleteAction() const { return mDeleteAction; }
     KAction *trashThreadAction() const { return mTrashThreadAction; }
     KAction *deleteThreadAction() const { return mDeleteThreadAction; }
@@ -158,22 +150,16 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     KMail::MessageActions *messageActions() const { return mMsgActions; }
 
     KActionMenu *threadStatusMenu() const { return mThreadStatusMenu; }
-    KActionMenu *moveActionMenu() const{ return mMoveActionMenu; }
-    KActionMenu *mopyActionMenu() const { return mCopyActionMenu; }
+    KAction *moveActionMenu() const{ return mMoveActionMenu; }
+    KAction *mopyActionMenu() const { return mCopyActionMenu; }
     KActionMenu *applyFilterActionsMenu() const { return mApplyFilterActionsMenu; }
 
     KToggleAction *watchThreadAction() const { return mWatchThreadAction; }
     KToggleAction *ignoreThreadAction() const { return mIgnoreThreadAction; }
 
-    /**
-     * Returns the currently active folder (may be 0 => root or searches active)
-     */
-    KMFolder *activeFolder() const;
 
     void toggleSystemTray();
 
-    void updateListFilterAction();
-
     /**
       Returns a list of all KMMainWidgets. Warning, the list itself can be 0.
       @return the list of all main widgets, or 0 if it is not yet initialized
@@ -188,31 +174,30 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     QList<QAction*> actionList();
 
     QLabel* vacationScriptIndicator() const;
-    void updateVactionScriptStatus() { updateVactionScriptStatus( mVacationIndicatorActive ); }
+    void updateVacationScriptStatus() { updateVacationScriptStatus( mVacationIndicatorActive ); }
+
+    MailCommon::FolderTreeView *folderTreeView() const {
+      return mFolderTreeWidget->folderTreeView();
+    }
+
+    /** Returns the XML GUI client. */
+    KXMLGUIClient* guiClient() const { return mGUIClient; }
+
+    KMail::TagActionManager *tagActionManager() const {
+      return mTagActionManager;
+    }
+
+    KMail::FolderShortcutActionManager *folderShortcutActionManager() const {
+      return mFolderShortcutActionManager;
+    }
 
   public slots:
     // Moving messages around
-
     /**
      * This will ask for a destination folder and move the currently selected
      * messages (in MessageListView) into it.
      */
-    void slotMoveMsg();
-
-    /**
-     * This will move the currently selected
-     * messages (in MessageListView) into the specified folder.
-     */
-    void slotMoveMsgToFolder( KMFolder *dest );
-
-    /**
-     * This will move the currently selected
-     * messages (in MessageListView) into the folder specified
-     * by static_cast< KMFolder * >( act->data().value< void * >() ).
-     * Note that this function TRUSTS the returned folder to be valid.
-     * Useful for connecting popup menus.
-     */
-    void slotMoveSelectedMessagesToFolder( QAction * act );
+    void slotMoveSelectedMessageToFolder();
 
     // Copying messages around
 
@@ -220,53 +205,36 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
      * This will ask for a destination folder and copy the currently selected
      * messages (in MessageListView) into it.
      */
-    void slotCopyMsg();
-
-    /**
-     * This will copy the currently selected
-     * messages (in MessageListView) into the specified folder.
-     */
-    void slotCopyMsgToFolder( KMFolder *dest );
-
-    /**
-     * This will copy the currently selected
-     * messages (in MessageListView) into the folder specified
-     * by static_cast< KMFolder * >( act->data().value< void * >() ).
-     * Note that this function TRUSTS the returned folder to be valid.
-     * Useful for connecting popup menus.
-     */
-    void slotCopySelectedMessagesToFolder( QAction * act );
+    void slotCopySelectedMessagesToFolder();
 
     /**
      * Implements the "move to trash" action
      */
-    void slotTrashMsg();
+    void slotTrashSelectedMessages();
 
     void slotCheckMail();
 
+    void slotCheckMailOnStartup();
+
     /**
       Select the given folder
       If the folder is 0 the intro is shown
     */
-    void folderSelected( KMFolder*, bool forceJumpToUnread = false, bool preferNewTabForOpening = false );
-
-    /**
-      Reselect current folder
-    */
-    void folderSelected();
-
-    void slotMsgSelected( KMMessage * );
+    void folderSelected( const Akonadi::Collection & col );
 
     /**
       Open a separate viewer window containing the specified message.
     */
-    void slotMsgActivated( KMMessage * );
+    void slotMessageActivated( const Akonadi::Item & );
 
     /**
-      Change the current folder, select a message in the current folder
+      Opens mail in the internal viewer.
     */
-    void slotSelectFolder(KMFolder*);
-    void slotSelectMessage(KMMessage*);
+    void slotMessageSelected( const Akonadi::Item & );
+
+    void slotItemsFetchedForActivation( const Akonadi::Item::List &list );
+    void slotMessageStatusChangeRequest(  const Akonadi::Item &, const Akonadi::MessageStatus &, const Akonadi::MessageStatus & );
+
 
     void slotReplaceMsgByUnencryptedVersion();
 
@@ -281,31 +249,13 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void startUpdateMessageActionsTimer();
 
     /** Update message actions */
-    void updateMessageActions();
-
-    /** Launch subscription-dialog (server side) */
-    void slotSubscriptionDialog();
-
-    /** Launch dialog for local (client side) subscription configuration */
-    void slotLocalSubscriptionDialog();
+    void updateMessageActions( bool fast = false );
+    void updateMessageActionsDelayed();
 
     /** Clear and create actions for marked filters */
     void clearFilterActions();
     void initializeFilterActions();
 
-    /** Create IMAP-account-related actions if applicable */
-    void initializeIMAPActions() { initializeIMAPActions( true ); }
-
-    /** Create actions for the folder shortcuts. */
-    void initializeFolderShortcutActions();
-
-    /** Add, remove or adjust the folder's shortcut. */
-    void slotShortcutChanged( KMFolder *folder );
-
-    /** Clear and create actions for message tag toggling */
-    void clearMessageTagActions();
-
-    void initializeMessageTagActions();
 
     /** Trigger the dialog for editing out-of-office scripts.  */
     void slotEditVacation();
@@ -313,13 +263,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     /** Adds if not existing/removes if existing the tag identified by @p aLabel
         in all selected messages */
     void slotUpdateMessageTagList( const QString &aLabel );
-
-    /** If @p aCount is 0, disables all tag related actions in menus.
-        If @p aCount is 1, Checks/unchecks according to the selected message's tag list.
-        If @p aCount is >1, changes labels of the actions to "Toggle <tag>"
-       @param aCount Number of selected messages
-    */
-    void updateMessageTagActions( const int aCount );
+    void slotSelectMoreMessageTagList();
 
     /**
      * Convenience function to get the action collection in a list.
@@ -330,35 +274,35 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
      */
     QList<KActionCollection*> actionCollections() const;
 
-    /**
-     * Sets the list of copied/cut messages.
-     * @param msgs A list of serial numbers.
-     * @param move if true, the messages were cut
-     */
-    void setMessageClipboardContents( const QList< quint32 > &msgs, bool move );
 
-    /**
-     * Open the "Folder Properties" dialogue.
-     * @param whichPage The page (tab) of the dialogue to initially show.
-     */
-    void slotModifyFolder( KMMainWidget::PropsPage whichPage = KMMainWidget::PropsGeneral );
+    KAction *akonadiStandardAction( Akonadi::StandardActionManager::Type type );
+    KAction *akonadiStandardAction( Akonadi::StandardMailActionManager::Type type );
+    Akonadi::StandardMailActionManager *standardMailActionManager() const { return mAkonadiStandardActionManager; }
+
+    void refreshMessageListSelection();
+
+    void slotStartCheckMail();
+    void slotEndCheckMail();
+    void slotEndCheckFetchCollectionsDone(KJob* job);
+
+    void slotCollectionProperties();
+
+    void slotSelectCollectionFolder( const Akonadi::Collection & col );
 
   signals:
     void messagesTransfered( bool );
     void captionChangeRequest( const QString &caption );
 
   protected:
+    void restoreCollectionFolderViewConfig();
     void setupActions();
     void createWidgets();
     void deleteWidgets();
     void layoutSplitters();
-    void showMsg( KMReaderWin *win, KMMessage *msg );
-    void updateFileMenu();
-    void newFromTemplate( KMMessage *msg );
+    void newFromTemplate( const Akonadi::Item& );
+    void moveSelectedMessagesToFolder( const Akonadi::Collection & dest );
+    void copySelectedMessagesToFolder( const Akonadi::Collection& dest );
 
-    // helper functions for keeping reference to mFolder
-    void openFolder();
-    void closeFolder();
 
     virtual void showEvent( QShowEvent *event );
 
@@ -372,33 +316,27 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     KSharedConfig::Ptr config();
 
   protected slots:
+    void updateFileMenu();
     void slotCheckOneAccount( QAction* );
-    void slotMailChecked( bool newMail, bool sendOnCheck,
-                          const QMap<QString, int> & newInFolder );
     void getAccountMenu();
     void getTransportMenu();
     void slotHelp();
     void slotFilter();
-    void slotPopFilter();
     void slotManageSieveScripts();
     void slotAddrBook();
     void slotImport();
     void slotCompose();
     void slotPostToML();
     void slotFolderMailingListProperties();
-    void slotFolderShortcutCommand();
+    void slotShowFolderShortcutDialog();
     void slotExpireFolder();
     void slotExpireAll();
-    void slotInvalidateIMAPFolders();
-    void slotMarkAllAsRead();
     void slotArchiveFolder();
     void slotRemoveFolder();
+    void slotDelayedRemoveFolder( KJob* );
     void slotEmptyFolder();
-    void slotCompactFolder();
-    void slotRefreshFolder();
-    void slotTroubleshootFolder();
-    void slotTroubleshootMaildir();
-    void slotCompactAll();
+    void slotAddFavoriteFolder();
+    void slotShowSelectedFolderInPane();
     void slotOverrideHtml();
     void slotOverrideHtmlLoadExt();
     void slotMessageQueuedOrDrafted();
@@ -418,13 +356,11 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotStartCertManager();
     void slotStartWatchGnuPG();
     void slotApplyFilters();
-    int slotFilterMsg(KMMessage *msg);
     void slotExpandThread();
     void slotExpandAllThreads();
     void slotCollapseThread();
     void slotCollapseAllThreads();
     void slotShowMsgSrc();
-    void slotSetThreadStatusNew();
     void slotSetThreadStatusUnread();
     void slotSetThreadStatusRead();
     void slotSetThreadStatusImportant();
@@ -435,11 +371,12 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotSendQueuedVia( QAction* item );
     void slotOnlineStatus();
     void slotUpdateOnlineStatus( GlobalSettings::EnumNetworkState::type );
-    void slotMsgPopup(KMMessage &msg, const KUrl &aUrl, const QPoint&);
+    void slotNetworkStatusChanged ( Solid::Networking::Status );
+    void slotMessagePopup(const Akonadi::Item& ,const KUrl&,const QPoint& );
+    void slotDelayedMessagePopup( KJob *job );
     void slotMarkAll();
     void slotFocusQuickSearch();
-    void slotSearch();
-    void slotSearchClosed();
+    bool slotSearch();
     void slotFind();
     void slotIntro();
     void slotShowStartupFolder();
@@ -449,7 +386,6 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotAntiVirusWizard();
     void slotFilterLogViewer();
     void slotAccountWizard();
-
     /** Message navigation */
     void slotSelectNextMessage();
     void slotExtendSelectionToNextMessage();
@@ -468,6 +404,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotDisplayCurrentMessage();
 
     void slotShowNewFromTemplate();
+    void slotDelayedShowNewFromTemplate( KJob* );
     void slotNewFromTemplate( QAction* );
 
     /** Update the undo action */
@@ -475,19 +412,11 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
 
     /** Update html and threaded messages preferences in Folder menu. */
     void updateFolderMenu();
-    /**
-      Enable or disable the "mark all as read" action. Needs to happen more
-      often than the other updates and is therefor in its own method.
-    */
-    void updateMarkAsReadAction();
 
     /** Settings menu */
 
     /** XML-GUI stuff */
     void slotEditNotifications();
-    void slotEditKeys();
-
-    void removeDuplicates();
 
     /** Slot to reply to a message */
     void slotCustomReplyToMsg( const QString &tmpl );
@@ -498,27 +427,12 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotCustomForwardMsg( const QString &tmpl );
     void slotNoQuoteReplyToMsg();
     void slotSubjectFilter();
-    void slotMailingListFilter();
     void slotFromFilter();
     void slotToFilter();
-    void slotPrintMsg();
     void slotCreateTodo();
-    void slotCopyMessages();
-    void slotCutMessages();
-    void slotPasteMessages();
 
     void slotConfigChanged();
 
-    /**
-      Remove the shortcut actions associated with a folder.
-    */
-    void slotFolderRemoved( KMFolder *folder );
-
-    /**
-     * Reopens the folder if it was closed because of a rename
-     */
-    void folderClosed( KMFolder *folder );
-
     /** Show a splash screen for the longer-lasting operation */
     void slotShowBusySplash();
 
@@ -528,96 +442,92 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     */
     void showOfflinePage();
 
-    void updateVactionScriptStatus( bool active );
+    void updateVacationScriptStatus( bool active );
+
+
+    void slotShowExpiryProperties();
+    void slotItemAdded( const Akonadi::Item &, const Akonadi::Collection& col);
+    void slotItemRemoved( const Akonadi::Item & );
+    void slotItemMoved( Akonadi::Item item, Akonadi::Collection from, Akonadi::Collection to );
+    void slotCollectionStatisticsChanged( const Akonadi::Collection::Id, const Akonadi::CollectionStatistics& );
+
+    void slotAkonadiStandardActionUpdated();
+    void slotCollectionChanged( const Akonadi::Collection&, const QSet<QByteArray>& );
+    void slotCreateNewTab( bool );
+    void slotShowNotification();
 
   private:
-    void updateCutCopyPasteActions();
-    void fillMessageClipboard();
+    void showNotifications();
 
     /** Get override character encoding. */
     QString overrideEncoding() const;
 
-    void initializeIMAPActions( bool setState );
+    void moveMessageSelected( MessageList::Core::MessageItemSetReference ref, const Akonadi::Collection &dest, bool confirmOnDeletion = true );
 
-    /**
-      Helper which finds the associated account if there is a current
-      folder and it is an imap or disconnected imap one.
-    */
-    KMail::ImapAccountBase* findCurrentImapAccountBase();
+    void copyMessageSelected( const QList<Akonadi::Item> &selectMsg, const Akonadi::Collection &dest );
 
-    /**
-      Helper which finds the associated IMAP path if there is a current
-      folder and it is an imap or disconnected imap one.
-    */
-    QString findCurrentImapPath();
-
-    /** Update the custom template menus. */
-    void updateCustomTemplateMenus();
 
     /**
      * Move the messages referenced by the specified set to trash.
      * The set parameter must not be null and the ownership is passed
      * to this function.
      */
-    void trashMessageSet( KMail::MessageListView::MessageSet * set );
-
-    /**
-     * Move the messages referenced by the specified set to the specified destination folder.
-     * If folder is 0 then the messages are permanently deleted. If folder is 0 and
-     * confirmOnDeletion is true then a confirmation dialog is shown before deleting
-     * the messages. If folder is nonzero then the confirmOnDeletion value is ignored.
-     * The set parameter must not be null and the ownership is passed
-     * to this function.
-     */
-    void moveMessageSet(
-        KMail::MessageListView::MessageSet * set,
-        KMFolder * destination,
-        bool confirmOnDeletion = true
-      );
-
-    /**
-     * Copy the messages referenced by the specified set to the specified destination folder.
-     * The set parameter must not be null and the ownership is passed to this function.
-     */
-    void copyMessageSet(
-        KMail::MessageListView::MessageSet * set,
-        KMFolder * destination
-      );
-
+    void trashMessageSelected( MessageList::Core::MessageItemSetReference ref );
     /**
      * Set the status of the messages referenced by the specified set, eventually toggling it.
      * The set parameter must not be null and the ownership is passed to this function.
      */
-    void setMessageSetStatus(
-        KMail::MessageListView::MessageSet * set,
-        const KPIM::MessageStatus &status,
+    void setMessageSetStatus( const QList<Akonadi::Item> &select,
+        const Akonadi::MessageStatus &status,
         bool toggle
       );
-
-    /**
-     * This applies setMessageSetStatus() on the current thread.
-     */
-    void setCurrentThreadStatus( const KPIM::MessageStatus &status, bool toggle );
-
     /**
      * Toggles a tag for the messages referenced by the specified set.
      * The set parameter must not be null and the ownership is passed to this function.
      */
-    void toggleMessageSetTag(
-        KMail::MessageListView::MessageSet * set,
-        const QString &taglabel
-      );
+    void toggleMessageSetTag( const QList<Akonadi::Item> &select, const QString &taglabel );
+    /**
+     * This applies setMessageSetStatus() on the current thread.
+     */
+    void setCurrentThreadStatus( const Akonadi::MessageStatus &status, bool toggle );
+
+    void applyFilters( const QList<Akonadi::Item>& selectedMessages );
+    void applyFilters( const QVector<qlonglong>& selectedMessages );
+
+    /**
+     * Internal helper that creates the folder selection dialog used for the
+     * move and copy to folder actions on demand. Only folders where items can
+     * be added are listed.
+     */
+    MailCommon::FolderSelectionDialog* moveOrCopyToDialog();
+
+    /**
+     * Internal helper that creates the folder selection dialog used for
+     * jumping to folders, or adding them as favourites. All folders are listed.
+     */
+    MailCommon::FolderSelectionDialog* selectFromAllFoldersDialog();
+
+
+    void addInfoInNotification( const Akonadi::Collection&col, Akonadi::Item::Id id );
+    void updateInfoInNotification( const Akonadi::Collection& from, const Akonadi::Collection& to, Akonadi::Item::Id id );
+
+    /**
+     * Internal helper that applies the current settings so the
+     * favorite folder view.
+     */
+    void refreshFavoriteFoldersViewProperties();
+    bool excludeSpecialFolder( const Akonadi::Collection &collection );
 
   private slots:
     /**
      * Called when a "move to trash" operation is completed
      */
-    void slotTrashMessagesCompleted( KMCommand *command );
+    void slotTrashMessagesCompleted( KMMoveCommand *command );
 
     /**
      * Called when a "move" operation is completed
      */
-    void slotMoveMessagesCompleted( KMCommand *command );
+    void slotMoveMessagesCompleted( KMMoveCommand *command );
 
     /**
      * Called when a "copy" operation is completed
@@ -625,123 +535,110 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotCopyMessagesCompleted( KMCommand *command );
 
     void slotRequestFullSearchFromQuickSearch();
-    void slotMessageListViewCurrentFolderChanged( KMFolder * fld );
-    void slotFolderViewManagerFolderActivated( KMFolder * fld, bool middleClick );
-    void slotMessageStatusChangeRequest( KMMsgBase *msg, const KPIM::MessageStatus &set, const KPIM::MessageStatus & clear );
+    void slotFolderChanged( const Akonadi::Collection& );
 
-  private:
+    void itemsReceived(const Akonadi::Item::List &list );
+    void itemsFetchDone( KJob *job );
+
+    void slotCollectionPropertiesContinued( KJob* job );
+    void slotDeletionCollectionResult(KJob* job);
+
+private:
     // Message actions
-    KAction *mTrashAction, *mDeleteAction, *mTrashThreadAction,
+    KAction *mDeleteAction, *mTrashThreadAction,
       *mDeleteThreadAction, *mSaveAsAction, *mUseAction,
       *mSendAgainAction, *mApplyAllFiltersAction, *mFindInMessageAction,
       *mSaveAttachmentsAction, *mOpenAction, *mViewSourceAction,
-      *mFavoritesCheckMailAction, *mRefreshImapCacheAction,
-      *mMoveMsgToFolderAction;
-    // Composition actions
-    KAction *mPrintAction;
+      *mMoveMsgToFolderAction, *mCollectionProperties, *mSendQueued;
     // Filter actions
     KActionMenu *mFilterMenu;
     KAction *mSubjectFilterAction, *mFromFilterAction, *mToFilterAction,
         *mListFilterAction;
-
     KAction *mNextMessageAction, *mPreviousMessageAction;
-
+    KAction *mExpireConfigAction;
+    KAction *mAddFavoriteFolder;
     // Custom template actions menu
     KActionMenu *mTemplateMenu;
-    CustomTemplatesMenu *mCustomTemplateMenus;
 
-    KActionMenu *mThreadStatusMenu,
-      *mMoveActionMenu, *mCopyActionMenu, *mApplyFilterActionsMenu;
-    KAction *mMarkThreadAsNewAction;
+    KActionMenu *mThreadStatusMenu, *mApplyFilterActionsMenu;
+    KAction *mCopyActionMenu;
+    KAction *mMoveActionMenu;
     KAction *mMarkThreadAsReadAction;
     KAction *mMarkThreadAsUnreadAction;
     KToggleAction *mToggleThreadImportantAction;
     KToggleAction *mToggleThreadToActAction;
-    KToggleAction *mToggleThreadFlagAction;
-    KToggleAction* mSizeColumnToggle;
 
     KToggleAction *mWatchThreadAction, *mIgnoreThreadAction;
 
-    KMail::FavoriteFolderView    *mFavoriteFolderView;
-    QPointer<KMFolder> mFolder;
+    MailCommon::FavoriteCollectionWidget *mFavoriteCollectionsView;
+    Akonadi::FavoriteCollectionsModel *mFavoritesModel;
     QWidget      *mSearchAndTree;
-    KTreeWidgetSearchLine *mFolderQuickSearch;
-    KMail::MainFolderView *mMainFolderView;
-    KMail::FolderViewManager *mFolderViewManager;
     KMReaderWin  *mMsgView;
     QSplitter    *mSplitter1, *mSplitter2, *mFolderViewSplitter;
-    KMFolder     *mTemplateFolder;
-    QMenu        *mViewMenu, *mBodyPartsMenu;
-    KAction      *mlistFilterAction;
-    bool          mIntegrated;
-    bool          mBeepOnNew;
-    bool          mConfirmEmpty;
-    QString       mStartupFolder;
-    int           mMessageStatusId;
+    Akonadi::Collection mTemplateFolder;
     KUrl          mUrlCurrent;
     QMenu        *mActMenu;
     QMenu        *mSendMenu;
-    QMenu        *mFileMenu;
     bool          mLongFolderList;
     bool          mStartupDone;
     bool          mWasEverShown;
-    int copyId, moveId, htmlId, threadId;
     bool mHtmlPref, mHtmlLoadExtPref,
       mFolderHtmlPref, mFolderHtmlLoadExtPref,
       mReaderWindowActive, mReaderWindowBelow;
     bool mEnableFavoriteFolderView;
     bool mEnableFolderQuickSearch;
 
-    //  QPopupMenu *mMessageMenu;
-    KMail::SearchWindow *mSearchWin;
+    QPointer<KMail::SearchWindow> mSearchWin;
 
-    KAction *mNewFolderAction, *mModifyFolderAction, *mRemoveFolderAction,
-      *mExpireFolderAction, *mCompactFolderAction, *mRefreshFolderAction,
-      *mEmptyFolderAction, *mMarkAllAsReadAction, *mFolderMailingListPropertiesAction,
-      *mFolderShortCutCommandAction, *mTroubleshootFolderAction,
-      *mRemoveDuplicatesAction, *mArchiveFolderAction,
-      *mTroubleshootMaildirAction, *mPostToMailinglistAction;
+    KAction *mExpireFolderAction,
+      *mFolderMailingListPropertiesAction,
+      *mShowFolderShortcutDialogAction,
+      *mArchiveFolderAction,
+      *mPostToMailinglistAction;
     KToggleAction *mPreferHtmlAction, *mPreferHtmlLoadExtAction;
     KToggleAction *mFolderAction, *mHeaderAction, *mMimeAction;
 
     QTimer *menutimer;
     QTimer *mShowBusySplashTimer;
 
-    QPointer<KMail::Vacation> mVacation;
+    QPointer<KSieveUi::Vacation> mVacation;
 #if !defined(NDEBUG)
-    QPointer<KMail::SieveDebugDialog> mSieveDebugDialog;
+    QPointer<KSieveUi::SieveDebugDialog> mSieveDebugDialog;
 #endif
     KActionCollection *mActionCollection;
     QAction *mToolbarActionSeparator;
-    QAction *mMessageTagToolbarActionSeparator;
     QVBoxLayout *mTopLayout;
     bool mDestructed, mForceJumpToUnread, mShowingOfflineScreen;
     QList<QAction*> mFilterMenuActions;
     QList<QAction*> mFilterTBarActions;
     QList<KMMetaFilterActionCommand*> mFilterCommands;
-    QHash<QString,FolderShortcutCommand*> mFolderShortcutCommands;
-    QPointer<KMail::FolderJob> mJob;
-
-    QList<MessageTagPtrPair> mMessageTagMenuActions;
-    QList<QAction*> mMessageTagTBarActions;
-    QSignalMapper *mMessageTagToggleMapper;
 
+    KMail::TagActionManager *mTagActionManager;
+    KMail::FolderShortcutActionManager *mFolderShortcutActionManager;
     KMSystemTray *mSystemTray;
     KSharedConfig::Ptr mConfig;
     KXMLGUIClient *mGUIClient;
 
     KMail::MessageActions *mMsgActions;
-    KMail::MessageListView::Pane *mMessageListView;
+    Akonadi::StandardMailActionManager *mAkonadiStandardActionManager;
+    CollectionPane *mMessagePane;
+    QSharedPointer<MailCommon::FolderCollection> mCurrentFolder;
 
-    bool mOpenedImapFolder;
+    MailCommon::FolderTreeWidget *mFolderTreeWidget;
 
     KMail::StatusBarLabel *mVacationScriptIndicator;
     bool mVacationIndicatorActive;
     bool mGoToFirstUnreadMessageInSelectedFolder;
+    MessageList::Core::PreSelectionMode mPreSelectionMode;
 
-    // message clipboard
-    QList< quint32 > mMessageClipboard;
-    bool mMessageClipboardInCutMode;
+    /// Used during mail check to remember how many mails there are in the folders
+    QMap<Akonadi::Collection::Id, QList<Akonadi::Item::Id> > mCheckMail;
+
+    bool mCheckMailInProgress;
+    QTimer m_notificationTimer;
+
+    MailCommon::FolderSelectionDialog* mMoveOrCopyToDialog;
+    MailCommon::FolderSelectionDialog* mSelectFromAllFoldersDialog;
 };
 
 #endif
