@@ -51,10 +51,10 @@ protected:
 
 public:
   FolderTreeWidgetItemLabelColumnDelegate( FolderTreeWidget *parent )
-    : QStyledItemDelegate( parent ), mFolderTreeWidget( parent ) {}
+    : QStyledItemDelegate( parent ), mFolderTreeWidget( parent ) {};
 
   ~FolderTreeWidgetItemLabelColumnDelegate()
-  {}
+  {};
 
   virtual QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const
   {
@@ -441,9 +441,8 @@ void FolderTreeWidgetItem::setLabelText( const QString &label )
   mLabelText = label;
   // We set the text of the item so QStyle will compute the height correctly
   FolderTreeWidget * tree = dynamic_cast< FolderTreeWidget * >( treeWidget() );
-  Q_ASSERT ( tree );
   int idx = tree->labelColumnIndex();
-  if ( idx >= 0 )
+  if ( tree && idx >= 0 )
   {
     setText( idx, label );
     setTextAlignment( idx, Qt::AlignRight );
@@ -482,17 +481,15 @@ void FolderTreeWidgetItem::setTotalCount( int totalCount )
     totalCountToDisplay += mChildrenTotalCount;
 
   FolderTreeWidget * tree = dynamic_cast< FolderTreeWidget * >( treeWidget() );
-  if( tree ) {
-    int idx = tree->totalColumnIndex();
-    if ( idx >= 0 )
-    {
-      // FIXME: Why the "parent()" logic is hardwired here ?
-      if ( parent() || mAlwaysDisplayCounts || !isExpanded() )
-        setText( idx, QString::number( totalCountToDisplay ) );
-      else
-        setText( idx, QString() );
-      setTextAlignment( idx, Qt::AlignRight );
-    }
+  int idx = tree->totalColumnIndex();
+  if ( tree && idx >= 0 )
+  {
+    // FIXME: Why the "parent()" logic is hardwired here ?
+    if ( parent() || mAlwaysDisplayCounts || !isExpanded() )
+      setText( idx, QString::number( totalCountToDisplay ) );
+    else
+      setText( idx, QString() );
+    setTextAlignment( idx, Qt::AlignRight );
   }
 }
 
@@ -525,13 +522,11 @@ void FolderTreeWidgetItem::setDataSize( qint64 dataSize )
     txt = "-";
 
   FolderTreeWidget * tree = dynamic_cast< FolderTreeWidget * >( treeWidget() );
-  if( tree ) {
-    int idx = tree->dataSizeColumnIndex();
-    if ( idx >= 0 )
-    {
-      setText( idx, txt );
-      setTextAlignment( idx, Qt::AlignRight );
-    }
+  int idx = tree->dataSizeColumnIndex();
+  if ( tree && idx >= 0 )
+  {
+    setText( idx, txt );
+    setTextAlignment( idx, Qt::AlignRight );
   }
 }
 
@@ -623,3 +618,4 @@ QString FolderTreeWidgetItem::elidedLabelText( const QFontMetrics &metrics, unsi
 
 }
 
+#include "foldertreewidget.moc"
