@@ -28,13 +28,13 @@
 #include "kolistview.h"
 #include "koeventpopupmenu.h"
 
-#include <calendarviews/list/listview.h>
+#include <calendarsupport/calendar.h>
 
 #include <QVBoxLayout>
 
 using namespace KOrg;
 
-KOListView::KOListView( const Akonadi::ETMCalendar::Ptr &calendar,
+KOListView::KOListView( CalendarSupport::Calendar *calendar,
                         QWidget *parent, bool nonInteractive )
   : KOEventView( parent )
 {
@@ -84,15 +84,21 @@ KOListView::KOListView( const Akonadi::ETMCalendar::Ptr &calendar,
   connect( mListView, SIGNAL(toggleTodoCompletedSignal(Akonadi::Item)),
            SIGNAL(toggleTodoCompletedSignal(Akonadi::Item)) );
 
-  connect( mListView, SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)),
-           SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)) );
+  connect( mListView, SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,QString)),
+           SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,QString)) );
 
-  connect( mListView, SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)),
-           SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)) );
+  connect( mListView, SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,QString)),
+           SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,QString)) );
 
   connect( mListView, SIGNAL(dissociateOccurrencesSignal(Akonadi::Item,QDate)),
            SIGNAL(dissociateOccurrencesSignal(Akonadi::Item,QDate)) );
 
+  connect( mListView, SIGNAL(startMultiModify(QString)),
+           SIGNAL(startMultiModify(QString)) );
+
+  connect( mListView, SIGNAL(endMultiModify()),
+           SIGNAL(endMultiModify()) );
+
   connect( mListView, SIGNAL(newEventSignal()),
            SIGNAL(newEventSignal()) );
 
@@ -136,7 +142,7 @@ Akonadi::Item::List KOListView::selectedIncidences()
   return mListView->selectedIncidences();
 }
 
-KCalCore::DateList KOListView::selectedIncidenceDates()
+DateList KOListView::selectedIncidenceDates()
 {
   return mListView->selectedIncidenceDates();
 }
@@ -161,10 +167,9 @@ void KOListView::showIncidences( const Akonadi::Item::List &incidenceList, const
   mListView->showIncidences( incidenceList, date );
 }
 
-void KOListView::changeIncidenceDisplay( const Akonadi::Item & aitem,
-                                         Akonadi::IncidenceChanger::ChangeType changeType )
+void KOListView::changeIncidenceDisplay( const Akonadi::Item & aitem, int action )
 {
-  mListView->changeIncidenceDisplay( aitem, changeType );
+  mListView->changeIncidenceDisplay( aitem, action );
 }
 
 void KOListView::defaultItemAction( const QModelIndex &index )
@@ -202,9 +207,9 @@ void KOListView::clear()
   mListView->clear();
 }
 
-CalendarSupport::CalPrinterBase::PrintType KOListView::printType() const
+KOrg::CalPrinterBase::PrintType KOListView::printType() const
 {
-  return CalendarSupport::CalPrinterBase::Incidence;
+  return KOrg::CalPrinterBase::Incidence;
 }
 
 QSize KOListView::sizeHint() const
@@ -212,15 +217,16 @@ QSize KOListView::sizeHint() const
   return mListView->sizeHint();
 }
 
-void KOListView::setCalendar( const Akonadi::ETMCalendar::Ptr &cal )
+void KOListView::setCalendar( CalendarSupport::Calendar *cal )
 {
   KOEventView::setCalendar( cal );
   mPopupMenu->setCalendar( cal );
   mListView->setCalendar( cal );
 }
 
-void KOListView::setIncidenceChanger( Akonadi::IncidenceChanger *changer )
+void KOListView::setIncidenceChanger( CalendarSupport::IncidenceChanger *changer )
 {
   mListView->setIncidenceChanger( changer );
 }
 
+#include "kolistview.moc"
