@@ -23,7 +23,7 @@
 
 #include "core/item.h"
 
-#include "messagecore/utils/stringutil.h"
+#include "messagecore/stringutil.h"
 
 // See the MessageList::ItemPrivate::insertChildItem() function below for an explaination of this macro.
 #if __GNUC__ >= 3  //krazy:exclude=cpp
@@ -41,7 +41,7 @@ namespace Core
 class ItemPrivate
 {
 public:
-  explicit ItemPrivate( Item *owner )
+  ItemPrivate( Item *owner )
     : q( owner ),
       mChildItems( 0 ),
       mParent( 0 ),
@@ -193,7 +193,9 @@ public:
     if ( !mChildItems )
       return false; // not my child! (ugh... should assert ?)
 
-    const int idx = q->indexOfChildItem(child);
+    int idx = child->indexGuess();
+    if ( !q->childItemHasIndex( child, idx ) )
+      idx = q->indexOfChildItem( child );
 
     if ( idx > 0 )
     {
@@ -242,11 +244,9 @@ public:
   size_t mSize;                               ///< The size of the message in bytes
   QString mSender;                            ///< The sender of the message (or group sender)
   QString mReceiver;                          ///< The receiver of the message (or group receiver)
-  QString mSubject;                           ///< The subject of the message (or group subject)
-  qint64 mItemId;                             ///< The Akonadi item id
-  qint64 mParentCollectionId;                 ///< The Akonadi ID of collection that this particular item comes from (can be virtual collection)
-  Akonadi::MessageStatus mStatus;             ///< The status of the message (may be extended to groups in the future)
   int mThisItemIndexGuess;                    ///< The guess for the index in the parent's child list
+  QString mSubject;                           ///< The subject of the message (or group subject)
+  Akonadi::MessageStatus mStatus;             ///< The status of the message (may be extended to groups in the future)
   Item::Type mType : 4;                       ///< The type of this item
   Item::InitialExpandStatus mInitialExpandStatus : 4; ///< The expand status we have to honor when we attach to the viewable root
   bool mIsViewable : 1;                       ///< Is this item attacched to the viewable root ?
@@ -437,55 +437,6 @@ public:
   }
 };
 
-/**
- * A helper class used with MessageList::Item::childItemNeedsReSorting() and
- * MessageList::Item::insertChildItem().
- */
-class ItemImportantStatusComparator
-{
-public:
-  static inline bool firstGreaterOrEqual( Item * first, Item * second )
-  {
-    if ( !first->status().isImportant() )
-    {
-      // fist is unread
-      if ( !second->status().isImportant() )
-        return first->date() >= second->date(); // both are unread
-      // unread comes always first with respect to non-unread
-      return true;
-    }
-    if ( !second->status().isImportant() )
-      return false;
-    // both are read
-    return first->date() >= second->date();
-  }
-};
-
-/**
- * A helper class used with MessageList::Item::childItemNeedsReSorting() and
- * MessageList::Item::insertChildItem().
- */
-class ItemAttachmentStatusComparator
-{
-public:
-  static inline bool firstGreaterOrEqual( Item * first, Item * second )
-  {
-    if ( !first->status().hasAttachment() )
-    {
-      // fist is unread
-      if ( !second->status().hasAttachment() )
-        return first->date() >= second->date(); // both are unread
-      // unread comes always first with respect to non-unread
-      return true;
-    }
-    if ( !second->status().hasAttachment() )
-      return false;
-    // both are read
-    return first->date() >= second->date();
-  }
-};
-
-
 } // namespace Core
 
 } // namespace MessageList
