@@ -149,7 +149,7 @@ public:
        */
       Size                         = 6 | DisplaysText | CanUseCustomColor | ApplicableToMessageItems,
       /**
-       * The icon that displays the new/unread/read state (never disabled)
+       * The icon that displays the unread/read state (never disabled)
        */
       ReadStateIcon                = 7 | ApplicableToMessageItems | IsIcon,
       /**
@@ -205,13 +205,22 @@ public:
        */
       MostRecentDate               = 20 | DisplaysText | CanUseCustomColor | ApplicableToMessageItems | ApplicableToGroupHeaderItems,
       /**
-       * The combined icon that displays the new/unread/read/replied/forwarded state (never disabled)
+       * The combined icon that displays the unread/read/replied/forwarded state (never disabled)
        */
       CombinedReadRepliedStateIcon = 21 | ApplicableToMessageItems | IsIcon,
       /**
        * The list of MessageItem::Tag entries
        */
-      TagList                      = 22 | ApplicableToMessageItems | IsIcon
+      TagList                      = 22 | ApplicableToMessageItems | IsIcon,
+      /**
+       * Whether the message has a annotation/note
+       */
+      AnnotationIcon               = 23 | ApplicableToMessageItems | IsIcon | CanBeDisabled | IsClickable,
+
+      /**
+       * Whether the message is an invitation
+       */
+      InvitationIcon               = 24 | ApplicableToMessageItems | IsIcon
 #if 0
       TotalMessageCount
       UnreadMessageCount
@@ -233,6 +242,7 @@ public:
      unsigned int mFlags;             ///< The flags of the item
 
      QFont mFont;                     ///< The font to use with this content item, meaningful only if displaysText() returns true.
+     QString mFontKey;                ///< The font key to speedup theme positioning. QFont.key() is called too many times otherwise.
      QColor mCustomColor;             ///< The color to use with this content item, meaningful only if canUseCustomColor() return true.
 
   public:
@@ -240,12 +250,12 @@ public:
      * Creates a ContentItem with the specified type.
      * A content item must be added to a theme Row.
      */
-    ContentItem( Type type );
+    explicit ContentItem( Type type );
     /**
      * Creates a ContentItem that is a copy of the content item src.
      * A content item must be added to a theme Row.
      */
-    ContentItem( const ContentItem &src );
+    explicit ContentItem( const ContentItem &src );
 
   public:
     /**
@@ -410,6 +420,16 @@ public:
     const QFont & font() const
       { return mFont; };
 
+    /**
+     * Returns the font key used by this item. It may be a custom font key set by setFont()
+     * or the default application font (returned by KGlobalSettings::generalFont()).
+     * This setting is valid as long as you have called updateFontMetrics()
+     * with the appropriate paint device.
+     * It is primary used to avoid to calculate the key every time an item is displayed.
+     */
+    const QString & fontKey() const
+      { return mFontKey; };
+
     /**
      * Returns the custom color set for this item.
      * The return value is meaningful only if canUseCustomColor() returns true
@@ -438,7 +458,6 @@ public:
      * Handles content item loading (used by Theme::Row::load())
      */
     bool load( QDataStream &stream, int themeVersion );
-
   };
 
   /**
@@ -448,8 +467,8 @@ public:
   class Row
   {
   public:
-    Row();
-    Row( const Row &src );
+    explicit Row();
+    explicit Row( const Row &src );
     ~Row();
 
   private:
@@ -561,7 +580,7 @@ public:
         /**
          * Create a shared runtime data object
          */
-        SharedRuntimeData( bool currentlyVisible, int currentWidth );
+        explicit SharedRuntimeData( bool currentlyVisible, int currentWidth );
 
         /**
          * Destroy a shared runtime data object
@@ -583,7 +602,7 @@ public:
          * Returns the current number of reference counts, that is, the number of
          * Theme::Column objects that use this SharedRuntimeData instance.
          */
-        int referenceCount()
+        int referenceCount() const 
           { return mReferences; };
 
         /**
@@ -626,14 +645,14 @@ public:
     /**
      * Create an empty column with default settings
      */
-    Column();
+    explicit Column();
     /**
      * Create an exact copy of the column src.
      * The shared runtime data is not copied (only a reference is added).
      * If you need to create an independent clone then please use detach()
      * after the construction.
      */
-    Column( const Column &src );
+    explicit Column( const Column &src );
     /**
      * Kill a column object
      */
@@ -832,25 +851,30 @@ public:
   /**
    * Creates a totally uninitialized theme object.
    */
-  Theme();
+  explicit Theme();
 
   /**
    * Creates a theme object with the specified name and description.
    */
-  Theme( const QString &name, const QString &description );
+  explicit Theme( const QString &name, const QString &description, bool readOnly = false );
 
   /**
    * Creates an exact copy of the theme sharing the same runtime data.
    * If you need an exact clone please use detach() and generateUniqueId() just
    * after creation.
    */
-  Theme( const Theme &src );
+  explicit Theme( const Theme &src );
 
   /**
    * Destroys this theme object.
    */
   ~Theme();
 
+  static bool compareName( Theme *theme1, Theme *theme2 )
+  {
+      return ( theme1->name() < theme2->name() );
+  }
+
 public:
   /**
    * Which color do we use to paint group header background ?
