@@ -34,25 +34,25 @@
 #include "filtereditor.h"
 #include "emailsexporthandler.h"
 #include "emailsfilterproxymodel.h"
+#include "emailsguistatemanager.h"
 #include "emailsimporthandler.h"
 #include "mailactionmanager.h"
-#include "mailcommon/collectionpage/collectiongeneralpage.h"
-#include "mailcommon/collectionpage/collectionexpirypage.h"
-#include "mailcommon/filter/filtermanager.h"
-#include "mailcommon/kernel/mailkernel.h"
-#include "mailcommon/widgets/redirectdialog.h"
-#include "mailcommon/mdn/sendmdnhandler.h"
+#include "mailcommon/collectiongeneralpage.h"
+#include "mailcommon/filtermanager.h"
+#include "mailcommon/mailkernel.h"
+#include "mailcommon/redirectdialog.h"
+#include "mailcommon/sendmdnhandler.h"
 #include "mailthreadgroupercomparator.h"
-#include "messagecomposer/helper/messagehelper.h"
-#include "messagecomposer/settings/messagecomposersettings.h"
-#include "messagecore/helpers/messagehelpers.h"
+#include "messagecomposer/messagehelper.h"
+#include "messagecomposer/messagecomposersettings.h"
+#include "messagecore/messagehelpers.h"
 #include "messagelistproxy.h"
 #include "messagelistsettingscontroller.h"
-#include "messageviewer/settings/globalsettings.h"
-#include "messageviewer/header/headerstrategy.h"
-#include "messageviewer/header/headerstyle.h"
-#include "messageviewer/viewer/nodehelper.h"
-#include "messageviewer/viewer/viewer.h"
+#include "messageviewer/globalsettings.h"
+#include "messageviewer/headerstrategy.h"
+#include "messageviewer/headerstyle.h"
+#include "messageviewer/nodehelper.h"
+#include "messageviewer/viewer.h"
 #include "messageviewitem.h"
 #include "mobilekernel.h"
 #include "savemailcommand_p.h"
@@ -81,6 +81,7 @@
 #include <akonadi/kmime/standardmailactionmanager.h>
 #include <akonadi_next/quotacolorproxymodel.h>
 #include <akonadibreadcrumbnavigationfactory.h>
+#include <incidenceeditor-ng/groupwareintegration.h>
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kcmdlineargs.h>
@@ -96,13 +97,13 @@
 #include <kpimidentities/identitymanager.h>
 #include <kselectionproxymodel.h>
 #include <kstandarddirs.h>
-#include <mailcommon/filter/filteractions/filteraction.h>
-#include <mailcommon/folder/foldercollection.h>
-#include <mailcommon/util/mailutil.h>
-#include <pimcommon/util/pimutil.h>
+#include <mailcommon/expirypropertiesdialog.h>
+#include <mailcommon/filteraction.h>
+#include <mailcommon/foldercollection.h>
+#include <mailcommon/mailutil.h>
 #include <mailtransport/transportmanager.h>
-#include <messagecomposer/sender/akonadisender.h>
-#include <messagecore/utils/stringutil.h>
+#include <messagecomposer/akonadisender.h>
+#include <messagecore/stringutil.h>
 #include <qmllistselectionmodel.h>
 #include <qmlcheckableproxymodel.h>
 
@@ -110,16 +111,22 @@
 #include <QtCore/QSignalMapper>
 #include <QtCore/QTimer>
 #include <QtDBus/QDBusConnection>
-#include <QDeclarativeContext>
-#include <QLabel>
-#include <QItemSelectionModel>
-#include <QTreeView>
+#include <QtDeclarative/QDeclarativeContext>
+#include <QtGui/QLabel>
+#include <QtGui/QItemSelectionModel>
+#include <QtGui/QTreeView>
+
+#ifdef _WIN32_WCE
+#include <identitypage.h>
+#include <kcomponentdata.h>
+#endif
 
 #ifdef KDEQMLPLUGIN_STATIC
 #include "runtime/qml/kde/kdeintegration.h"
 #endif
 
 Q_DECLARE_METATYPE( KMime::Content* )
+QML_DECLARE_TYPE( EmailsGuiStateManager )
 QML_DECLARE_TYPE( MessageViewer::MessageViewItem )
 QML_DECLARE_TYPE( DeclarativeConfigWidget )
 QML_DECLARE_TYPE( DeclarativeSearchWidget )
@@ -139,17 +146,17 @@ MainView::MainView(QWidget* parent)
     mAskingToGoOnline( false ),
     mTransportDialog( 0 ),
     m_grouperComparator( 0 ),
-    mQuotaColorProxyModel( new QuotaColorProxyModel( this ) )
+    mQuotaColorProxyModel( new QuotaColorProxyModel( this ) ),
+    mNetworkAccessHelper( 0 )
 {
   qRegisterMetaType<KMime::Content*>();
 
   updateConfig();
 
-  QDBusConnection::sessionBus().registerService( QLatin1String("org.kde.kmailmobile.composer") );
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/composer"), this, QDBusConnection::ExportScriptableSlots );
+  QDBusConnection::sessionBus().registerService( "org.kde.kmailmobile.composer" );
+  QDBusConnection::sessionBus().registerObject( "/composer", this, QDBusConnection::ExportScriptableSlots );
 
   Akonadi::CollectionPropertiesDialog::registerPage( new MailCommon::CollectionGeneralPageFactory );
-  Akonadi::CollectionPropertiesDialog::registerPage( new MailCommon::CollectionExpiryPageFactory );
 }
 
 MainView::~MainView()
@@ -302,7 +309,7 @@ KMime::Content *MainView::createAttachment( const KUrl &url ) const
   QByteArray coded = KCodecs::base64Encode( contents, true );
   KMime::Headers::ContentDisposition *d = new KMime::Headers::ContentDisposition;
   d->setDisposition( KMime::Headers::CDattachment );
-  d->setFilename( fileName.section(QLatin1Char('/'), -1) );
+  d->setFilename( fileName.section('/', -1) );
   d->setDisposition( KMime::Headers::CDattachment );
 
   KMime::Content *a = new KMime::Content();
@@ -364,42 +371,42 @@ QAbstractItemModel* MainView::createItemModelContext(QDeclarativeContext* contex
   setItemNaigationAndActionSelectionModels(itemNavigationSelectionModel, itemActionSelectionModel);
 
   if ( _listProxy ) {
-    context->setContextProperty( QLatin1String("itemModel"), _listProxy );
+    context->setContextProperty( "itemModel", _listProxy );
 
     QMLListSelectionModel *qmlItemNavigationSelectionModel = new QMLListSelectionModel( itemNavigationSelectionModel, this );
     QMLListSelectionModel *qmlItemActionSelectionModel = new QMLListSelectionModel( itemActionSelectionModel, this );
 
-    context->setContextProperty( QLatin1String("_itemNavigationModel"), QVariant::fromValue( static_cast<QObject*>( qmlItemNavigationSelectionModel ) ) );
-    context->setContextProperty( QLatin1String("_itemActionModel"), QVariant::fromValue( static_cast<QObject*>( qmlItemActionSelectionModel ) ) );
+    context->setContextProperty( "_itemNavigationModel", QVariant::fromValue( static_cast<QObject*>( qmlItemNavigationSelectionModel ) ) );
+    context->setContextProperty( "_itemActionModel", QVariant::fromValue( static_cast<QObject*>( qmlItemActionSelectionModel ) ) );
 
     Akonadi::BreadcrumbNavigationFactory *bulkActionBnf = new Akonadi::BreadcrumbNavigationFactory( this );
     bulkActionBnf->createCheckableBreadcrumbContext( entityTreeModel(), this );
-    context->setContextProperty( QLatin1String("_bulkActionBnf"), QVariant::fromValue( static_cast<QObject*>( bulkActionBnf ) ) );
+    context->setContextProperty( "_bulkActionBnf", QVariant::fromValue( static_cast<QObject*>( bulkActionBnf ) ) );
   }
 
   m_threadsModel = new ThreadModel(_listProxy, this);
 
-  context->setContextProperty(QLatin1String( "_threads"), m_threadsModel );
+  context->setContextProperty( "_threads", m_threadsModel );
 
   QItemSelectionModel *itemThreadModel = new QItemSelectionModel( model, this );
 
   m_threadContentsModel = new KSelectionProxyModel(itemThreadModel, this);
   m_threadContentsModel->setSourceModel(_listProxy);
-  m_threadContentsModel->setObjectName(QLatin1String("threadContentsModel"));
+  m_threadContentsModel->setObjectName("threadContentsModel");
 
-  context->setContextProperty( QLatin1String("_threadContents"), m_threadContentsModel );
+  context->setContextProperty( "_threadContents", m_threadContentsModel );
 
   ThreadSelectionModel *threadSelector = new ThreadSelectionModel(m_threadsModel, itemThreadModel, itemNavigationModel, this);
 
   QMLListSelectionModel *qmlThreadSelector = new QMLListSelectionModel(threadSelector, this);
 
-  context->setContextProperty(QLatin1String("_threadSelector"), qmlThreadSelector );
+  context->setContextProperty("_threadSelector", qmlThreadSelector );
 
   KLinkItemSelectionModel *threadMailSelector = new KLinkItemSelectionModel(m_threadContentsModel, itemNavigationModel, this);
 
   QMLListSelectionModel *qmlThreadMailSelector = new QMLListSelectionModel(threadMailSelector, this);
 
-  context->setContextProperty(QLatin1String("_threadMailSelector"), qmlThreadMailSelector );
+  context->setContextProperty("_threadMailSelector", qmlThreadMailSelector );
 
   connect( this, SIGNAL(collectionSelectionChanged()),
            this, SLOT(slotCollectionSelectionChanged()) );
@@ -426,6 +433,10 @@ bool MainView::doNotUseFilterLineEditInCurrentState() const
 
 void MainView::doDelayedInit()
 {
+  if ( !IncidenceEditorNG::GroupwareIntegration::isActive() ) {
+    IncidenceEditorNG::GroupwareIntegration::setGlobalUiDelegate( new GroupwareUiDelegate );
+  }
+
   static const bool debugTiming = KCmdLineArgs::parsedArgs()->isSet( "timeit" );
   MobileKernel::self()->setFolderCollectionMonitor( monitor() );
 
@@ -443,23 +454,23 @@ void MainView::doDelayedInit()
   mEmailTemplateModel = new TemplateEmailModel( mTemplateSelectionModel, this );
   mEmailTemplateModel->setSourceModel( entityTreeModel() );
   mEmailTemplateModel->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
-  rootContext()->setContextProperty( QLatin1String("_emailTemplateModel"), mEmailTemplateModel );
+  rootContext()->setContextProperty( "_emailTemplateModel", mEmailTemplateModel );
 
   FilterEditor *filterEditor = new FilterEditor( actionCollection(), this );
-  rootContext()->setContextProperty( QLatin1String("filterEditor"), filterEditor );
-  rootContext()->setContextProperty( QLatin1String("filterModel"), filterEditor->model() );
+  rootContext()->setContextProperty( "filterEditor", filterEditor );
+  rootContext()->setContextProperty( "filterModel", filterEditor->model() );
 
   mAclEditor = new AclEditor( actionCollection(), this );
-  rootContext()->setContextProperty( QLatin1String("aclEditor"), mAclEditor );
-  rootContext()->setContextProperty( QLatin1String("aclModel"), mAclEditor->model() );
+  rootContext()->setContextProperty( "aclEditor", mAclEditor );
+  rootContext()->setContextProperty( "aclModel", mAclEditor->model() );
 
   VacationManager *vacationManager = new VacationManager( actionCollection(), this, this );
-  rootContext()->setContextProperty( QLatin1String("vacationManager"), vacationManager );
+  rootContext()->setContextProperty( "vacationManager", vacationManager );
 
   mMessageListSettingsController = new MessageListSettingsController( this );
-  actionCollection()->addAction( QLatin1String("messagelist_change_settings"), mMessageListSettingsController->editAction() );
-  actionCollection()->action( QLatin1String("messagelist_change_settings") )->setText( i18n( "Messagelist Display Format" ) );
-  rootContext()->setContextProperty( QLatin1String("messageListSettings"), mMessageListSettingsController );
+  actionCollection()->addAction( "messagelist_change_settings", mMessageListSettingsController->editAction() );
+  actionCollection()->action( "messagelist_change_settings" )->setText( i18n( "Messagelist Display Format" ) );
+  rootContext()->setContextProperty( "messageListSettings", mMessageListSettingsController );
   connect( mMessageListSettingsController, SIGNAL(settingsChanged(MessageListSettings)),
            this, SLOT(messageListSettingsChanged(MessageListSettings)) );
 
@@ -472,6 +483,7 @@ void MainView::doDelayedInit()
   qmlRegisterType<MessageViewer::MessageViewItem>( "org.kde.messageviewer", 4, 5, "MessageView" );
   qmlRegisterType<DeclarativeConfigWidget>( "org.kde.akonadi.mail", 4, 5, "ConfigWidget" );
   qmlRegisterType<DeclarativeSearchWidget>( "org.kde.akonadi.mail", 4, 5, "SearchWidget" );
+  qmlRegisterUncreatableType<EmailsGuiStateManager>( "org.kde.akonadi.mail", 4, 5, "EmailsGuiStateManager", QLatin1String( "This type is only exported for its enums" ) );
 #ifdef KDEQMLPLUGIN_STATIC
   rootContext()->setContextProperty( QLatin1String( "KDE" ), new KDEIntegration( this ) );
 #endif
@@ -484,33 +496,43 @@ void MainView::doDelayedInit()
   mailActionManager->setItemSelectionModel( itemSelectionModel() );
   mailActionManager->setItemActionSelectionModel( itemActionModel() );
 
-  connect( actionCollection()->action( QLatin1String("mark_message_important") ), SIGNAL(triggered(bool)), SLOT(markImportant(bool)) );
-  connect( actionCollection()->action( QLatin1String("mark_message_action_item") ), SIGNAL(triggered(bool)), SLOT(markMailTask(bool)) );
-  connect( actionCollection()->action( QLatin1String("send_queued_emails") ), SIGNAL(triggered(bool)), SLOT(sendQueued()) );
-  connect( actionCollection()->action( QLatin1String("send_queued_emails_via") ), SIGNAL(triggered(bool)), SLOT(sendQueuedVia()) );
-  connect( actionCollection()->action( QLatin1String("message_reply") ), SIGNAL(triggered(bool)), SLOT(replyToMessage()) );
-  connect( actionCollection()->action( QLatin1String("message_reply_to_list") ), SIGNAL(triggered(bool)), SLOT(replyToMailingList()) );
-  connect( actionCollection()->action( QLatin1String("message_reply_without_quoting") ), SIGNAL(triggered(bool)), SLOT(replyWithoutQuoting()) );
-  connect( actionCollection()->action( QLatin1String("message_forward_as_attachment") ), SIGNAL(triggered(bool)), SLOT(forwardAsAttachment()) );
-  connect( actionCollection()->action( QLatin1String("message_redirect") ), SIGNAL(triggered(bool)), SLOT(redirect()) );
-  connect( actionCollection()->action( QLatin1String("message_send_again" )), SIGNAL(triggered(bool)), SLOT(sendAgain()) );
-  connect( actionCollection()->action( QLatin1String("message_edit") ), SIGNAL(triggered(bool)), SLOT(sendAgain()) ); //do the same under a different name
-  connect( actionCollection()->action( QLatin1String("message_find_in") ), SIGNAL(triggered(bool)), SLOT(findInMessage()) );
-  connect( actionCollection()->action( QLatin1String("message_save_as") ), SIGNAL(triggered(bool)), SLOT(saveMessage()) );
-  connect( actionCollection()->action( QLatin1String("message_fixed_font") ), SIGNAL(triggered(bool)), SLOT(useFixedFont()) );
-  connect( actionCollection()->action( QLatin1String("save_favorite") ), SIGNAL(triggered(bool)), SLOT(saveFavorite()) );
-  connect( actionCollection()->action( QLatin1String("prefer_html_to_plain") ), SIGNAL(triggered(bool)), SLOT(preferHTML(bool)) );
-  connect( actionCollection()->action( QLatin1String("prefer_html_to_plain_viewer") ), SIGNAL(triggered(bool)), SLOT(preferHtmlViewer(bool)) );
-  connect( actionCollection()->action( QLatin1String("load_external_ref") ), SIGNAL(triggered(bool)), SLOT(loadExternalReferences(bool)) );
-  connect( actionCollection()->action( QLatin1String("move_all_to_trash") ), SIGNAL(triggered(bool)), SLOT(moveToOrEmptyTrash()) );
-  connect( actionCollection()->action( QLatin1String("apply_filters") ), SIGNAL(triggered(bool)), SLOT(applyFilters()) );
-  connect( actionCollection()->action( QLatin1String("apply_filters_bulk_action") ), SIGNAL(triggered(bool)), SLOT(applyFiltersBulkAction()) );
+  connect( actionCollection()->action( "mark_message_important" ), SIGNAL(triggered(bool)), SLOT(markImportant(bool)) );
+  connect( actionCollection()->action( "mark_message_action_item" ), SIGNAL(triggered(bool)), SLOT(markMailTask(bool)) );
+  connect( actionCollection()->action( "send_queued_emails" ), SIGNAL(triggered(bool)), SLOT(sendQueued()) );
+  connect( actionCollection()->action( "send_queued_emails_via" ), SIGNAL(triggered(bool)), SLOT(sendQueuedVia()) );
+  connect( actionCollection()->action( "message_reply" ), SIGNAL(triggered(bool)), SLOT(replyToMessage()) );
+  connect( actionCollection()->action( "message_reply_to_all" ), SIGNAL(triggered(bool)), SLOT(replyToAll()) );
+  connect( actionCollection()->action( "message_reply_to_author" ), SIGNAL(triggered(bool)), SLOT(replyToAuthor()) );
+  connect( actionCollection()->action( "message_reply_to_list" ), SIGNAL(triggered(bool)), SLOT(replyToMailingList()) );
+  connect( actionCollection()->action( "message_reply_without_quoting" ), SIGNAL(triggered(bool)), SLOT(replyWithoutQuoting()) );
+  connect( actionCollection()->action( "message_forward" ), SIGNAL(triggered(bool)), SLOT(forwardMessage()) );
+  connect( actionCollection()->action( "message_forward_as_attachment" ), SIGNAL(triggered(bool)), SLOT(forwardAsAttachment()) );
+  connect( actionCollection()->action( "message_redirect" ), SIGNAL(triggered(bool)), SLOT(redirect()) );
+  connect( actionCollection()->action( "message_send_again" ), SIGNAL(triggered(bool)), SLOT(sendAgain()) );
+  connect( actionCollection()->action( "message_edit" ), SIGNAL(triggered(bool)), SLOT(sendAgain()) ); //do the same under a different name
+  connect( actionCollection()->action( "message_find_in" ), SIGNAL(triggered(bool)), SLOT(findInMessage()) );
+  connect( actionCollection()->action( "message_save_as" ), SIGNAL(triggered(bool)), SLOT(saveMessage()) );
+  connect( actionCollection()->action( "message_fixed_font" ), SIGNAL(triggered(bool)), SLOT(useFixedFont()) );
+  connect( actionCollection()->action( "save_favorite" ), SIGNAL(triggered(bool)), SLOT(saveFavorite()) );
+  connect( actionCollection()->action( "prefer_html_to_plain" ), SIGNAL(triggered(bool)), SLOT(preferHTML(bool)) );
+  connect( actionCollection()->action( "prefer_html_to_plain_viewer" ), SIGNAL(triggered(bool)), SLOT(preferHtmlViewer(bool)) );
+  connect( actionCollection()->action( "load_external_ref" ), SIGNAL(triggered(bool)), SLOT(loadExternalReferences(bool)) );
+  connect( actionCollection()->action( "show_expire_properties" ), SIGNAL(triggered(bool)), SLOT(showExpireProperties()) );
+  connect( actionCollection()->action( "move_all_to_trash" ), SIGNAL(triggered(bool)), SLOT(moveToOrEmptyTrash()) );
+  connect( actionCollection()->action( "create_todo_reminder" ), SIGNAL(triggered(bool)), SLOT(createToDo()) );
+  connect( actionCollection()->action( "create_event" ), SIGNAL(triggered(bool)), SLOT(createEvent()) );
+  connect( actionCollection()->action( "apply_filters" ), SIGNAL(triggered(bool)), SLOT(applyFilters()) );
+  connect( actionCollection()->action( "apply_filters_bulk_action" ), SIGNAL(triggered(bool)), SLOT(applyFiltersBulkAction()) );
 
   connect( itemSelectionModel()->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(dataChanged()) );
 
-  KAction *action = new KAction( i18n( "New Email" ), this );
+  KAction *action = new KAction( i18n( "Identities" ), this );
+  connect( action, SIGNAL(triggered(bool)), SLOT(configureIdentity()) );
+  actionCollection()->addAction( "kmail_mobile_identities", action );
+
+  action = new KAction( i18n( "New Email" ), this );
   connect( action, SIGNAL(triggered(bool)), SLOT(startComposer()) );
-  actionCollection()->addAction( QLatin1String("add_new_mail"), action );
+  actionCollection()->addAction( "add_new_mail", action );
 
   action = new KAction( i18n( "Import Emails" ), this );
   connect( action, SIGNAL(triggered(bool)), SLOT(importItems()) );
@@ -553,9 +575,8 @@ void MainView::doDelayedInit()
   if ( !workOffline() ) {
     const Akonadi::AgentInstance::List lst = MailCommon::Util::agentInstances();
     foreach ( Akonadi::AgentInstance type, lst ) {
-        const QString identifier = type.identifier();
-      if ( PimCommon::Util::isImapResource(identifier) ||
-          identifier.contains( POP3_RESOURCE_IDENTIFIER ) ) {
+      if ( type.identifier().contains( IMAP_RESOURCE_IDENTIFIER ) ||
+          type.identifier().contains( POP3_RESOURCE_IDENTIFIER ) ) {
         type.setIsOnline( true );
       }
     }
@@ -575,9 +596,9 @@ void MainView::qmlInitialized(QDeclarativeView::Status status)
 
     const bool fixedFont = MessageViewer::GlobalSettings::self()->useFixedFont();
     item->viewer()->setUseFixedFont( fixedFont );
-    actionCollection()->action( QLatin1String("message_fixed_font") )->setChecked( fixedFont );
+    actionCollection()->action( "message_fixed_font" )->setChecked( fixedFont );
 
-    actionCollection()->action( QLatin1String("show_extended_headers") )->setChecked( true );
+    actionCollection()->action( "show_extended_headers" )->setChecked( true );
     toggleShowExtendedHeaders( true );
 
     connect( item->viewer(), SIGNAL(deleteMessage(Akonadi::Item)),
@@ -772,6 +793,11 @@ bool MainView::askToGoOnline()
       QAction *workOffLineAction = mMailActionManager->action( StandardActionManager::ToggleWorkOffline );
       workOffLineAction->setChecked( true );
       workOffLineAction->trigger();
+
+      if ( !mNetworkAccessHelper )
+        mNetworkAccessHelper = new KPIMUtils::NetworkAccessHelper( this );
+
+      mNetworkAccessHelper->establishConnection();
     }
   }
 
@@ -791,7 +817,7 @@ void MainView::sendQueuedVia()
   if ( !askToGoOnline() )
     return;
 
-  QList<MailTransport::Transport *> transports = MailTransport::TransportManager::self()->transports();
+  const QStringList availTransports= MailTransport::TransportManager::self()->transportNames();
 
   delete mTransportDialog;
   mTransportDialog = new QWidget( this, Qt::Dialog ); //not a real dialog though, should be done in QML
@@ -806,13 +832,14 @@ void MainView::sendQueuedVia()
   layout->addWidget( label );
   QSignalMapper *mapper = new QSignalMapper( mTransportDialog );
 
-  Q_FOREACH( MailTransport::Transport *transport, transports) {
-      QPushButton *button = new QPushButton( transport->name() );
-      layout->addWidget( button );
-      mapper->setMapping( button, transport->id() );
-      connect( button, SIGNAL(clicked()), mapper, SLOT(map()) );
+  Q_FOREACH( const QString &transport, availTransports ) {
+    QPushButton *button = new QPushButton( transport );
+    layout->addWidget( button );
+    mapper->setMapping( button, transport );
+    connect( button, SIGNAL(clicked()), mapper, SLOT(map()) );
   }
-  connect( mapper, SIGNAL(mapped(int)), this, SLOT(sendQueuedVia(int)));
+
+  connect( mapper, SIGNAL(mapped(QString)), this, SLOT(sendQueuedVia(QString)));
 
   QPushButton *button = new QPushButton( i18n( "Discard" ) );
   layout->addWidget( button );
@@ -821,9 +848,9 @@ void MainView::sendQueuedVia()
   mTransportDialog->show();
 }
 
-void MainView::sendQueuedVia( int transportId )
+void MainView::sendQueuedVia( const QString &transport )
 {
-  KernelIf->msgSender()->sendQueued( transportId );
+  KernelIf->msgSender()->sendQueued( transport );
   delete mTransportDialog;
   mTransportDialog = 0;
 }
@@ -913,7 +940,7 @@ void MainView::forwardFetchResult( KJob* job )
       return;
 
     factory.setFolderIdentity( MailCommon::Util::folderIdentity( item ) );
-    const KMime::Message::Ptr redirectMessage = factory.createRedirect( dlg.to(), dlg.cc(), dlg.bcc() );
+    const KMime::Message::Ptr redirectMessage = factory.createRedirect( dlg.to() );
     if ( !redirectMessage )
       return;
 
@@ -922,9 +949,9 @@ void MainView::forwardFetchResult( KJob* job )
     if ( !status.isRead() )
       MailCommon::FilterAction::sendMDN( item, KMime::MDN::Dispatched );
 
-    const MessageComposer::MessageSender::SendMethod method = (dlg.sendMode() == MailCommon::RedirectDialog::SendNow)
-                                               ? MessageComposer::MessageSender::SendImmediate
-                                               : MessageComposer::MessageSender::SendLater;
+    const MessageSender::SendMethod method = (dlg.sendMode() == MailCommon::RedirectDialog::SendNow)
+                                               ? MessageSender::SendImmediate
+                                               : MessageSender::SendLater;
 
     MobileKernel::self()->msgSender()->send( redirectMessage, method );
 
@@ -979,7 +1006,6 @@ void MainView::markImportant( bool checked )
   item.setFlags( status.statusFlags() );
 
   ItemModifyJob *job = new ItemModifyJob( item );
-  job->disableRevisionCheck();
   job->setIgnorePayload( true );
   connect( job, SIGNAL(result(KJob*)), SLOT(modifyDone(KJob*)) );
 }
@@ -1003,7 +1029,6 @@ void MainView::markMailTask( bool checked )
   item.setFlags( status.statusFlags() );
 
   ItemModifyJob *job = new ItemModifyJob( item );
-  job->disableRevisionCheck();
   job->setIgnorePayload( true );
   connect( job, SIGNAL(result(KJob*)), SLOT(modifyDone(KJob*)) );
 }
@@ -1099,17 +1124,30 @@ void MainView::dataChanged()
   MessageStatus status;
   status.setStatusFromFlags( item.flags() );
 
-  actionCollection()->action( QLatin1String("mark_message_important") )->setChecked( status.isImportant() );
-  actionCollection()->action( QLatin1String("mark_message_action_item") )->setChecked( status.isToAct() );
+  actionCollection()->action( "mark_message_important" )->setChecked( status.isImportant() );
+  actionCollection()->action( "mark_message_action_item" )->setChecked( status.isToAct() );
 }
 
 void MainView::configureIdentity()
 {
+#ifdef _WIN32_WCE
+  KComponentData instance( "kcmkmail_config_identity" ); // keep in sync with kmail for now to reuse kmail translations until after the string freeze
+  KMail::IdentityPage *page = new KMail::IdentityPage( instance, this );
+  page->setObjectName( "kcm_kpimidentities" );
+
+  KDialog dialog( this );
+  dialog.setMainWidget( page );
+  dialog.setButtons( KDialog::Ok | KDialog::Cancel );
+  dialog.setWindowState( Qt::WindowFullScreen );
+  connect( &dialog, SIGNAL(okClicked()), page, SLOT(save()) );
+  dialog.exec();
+#else
   KCMultiDialog dlg;
-  dlg.addModule( QLatin1String("kcm_kpimidentities") );
+  dlg.addModule( "kcm_kpimidentities" );
   dlg.currentPage()->setHeader( QLatin1String( "" ) ); // hide header to save space
   dlg.setButtons( KDialog::Ok | KDialog::Cancel );
   dlg.exec();
+#endif
 }
 
 bool MainView::isDraftThreadContent( int row )
@@ -1331,8 +1369,7 @@ void MainView::setupStandardActionManager( QItemSelectionModel *collectionSelect
            this, SLOT(launchAccountWizard()) );
 
   const QStringList pages = QStringList() << QLatin1String( "MailCommon::CollectionGeneralPage" )
-                                          << QLatin1String( "Akonadi::CachePolicyPage" )
-                                          << QLatin1String( "MailCommon::CollectionExpiryPage" );
+                                          << QLatin1String( "Akonadi::CachePolicyPage" );
 
   mMailActionManager->setCollectionPropertiesPageNames( pages );
 
@@ -1359,7 +1396,7 @@ void MainView::setupStandardActionManager( QItemSelectionModel *collectionSelect
 
   connect(mMailActionManager, SIGNAL(actionStateUpdated()), this, SLOT(mailActionStateUpdated()) );
 
-  actionCollection()->action( QLatin1String("synchronize_all_items") )->setText( i18n( "Synchronize All Accounts" ) );
+  actionCollection()->action( "synchronize_all_items" )->setText( i18n( "Synchronize All Accounts" ) );
 
   connect( collectionSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(folderChanged()) );
 }
@@ -1448,6 +1485,11 @@ ExportHandlerBase* MainView::exportHandler() const
   return new EmailsExportHandler();
 }
 
+GuiStateManager* MainView::createGuiStateManager() const
+{
+  return new EmailsGuiStateManager();
+}
+
 void MainView::saveMessage()
 {
   const Item item = currentItem();
@@ -1469,7 +1511,7 @@ QString MainView::itemStorageCollectionAsPath( const Akonadi::Item &item ) const
     path.prepend( index.data().toString() );
     index = index.parent();
     if ( index.isValid() )
-      path.prepend( QLatin1String(" / ") );
+      path.prepend( " / " );
   }
 
   return path;
@@ -1549,17 +1591,17 @@ void MainView::preferHTML(bool useHtml)
       const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
       Q_ASSERT( collection.isValid() );
 
-      KSharedConfigPtr config = KSharedConfig::openConfig( QLatin1String("kmail-mobilerc") );
-      KConfigGroup group( config, QString::fromLatin1( "c%1" ).arg( collection.id() ) );
+      KSharedConfigPtr config = KSharedConfig::openConfig( "kmail-mobilerc" );
+      KConfigGroup group( config, QString( "c%1" ).arg( collection.id() ) );
       group.writeEntry( "htmlMailOverride", useHtml );
     }
 
-    item->viewer()->setDisplayFormatMessageOverwrite( useHtml ? MessageViewer::Viewer::Html : MessageViewer::Viewer::Text );
+    item->viewer()->setHtmlOverride( useHtml );
     item->viewer()->update( MessageViewer::Viewer::Force );
   }
 
   // update the viewer specific state according to the folder wide state
-  QAction *action = actionCollection()->action( QLatin1String("prefer_html_to_plain_viewer") );
+  QAction *action = actionCollection()->action( "prefer_html_to_plain_viewer" );
   disconnect( action, SIGNAL(triggered(bool)), this, SLOT(preferHtmlViewer(bool)) );
   action->setChecked( useHtml );
   connect( action, SIGNAL(triggered(bool)), this, SLOT(preferHtmlViewer(bool)) );
@@ -1570,7 +1612,7 @@ void MainView::preferHtmlViewer( bool useHtml )
   MessageViewer::MessageViewItem* item = messageViewerItem();
 
   if ( item ) {
-    item->viewer()->setDisplayFormatMessageOverwrite( useHtml ? MessageViewer::Viewer::Html : MessageViewer::Viewer::Text );
+    item->viewer()->setHtmlOverride( useHtml );
     item->viewer()->update( MessageViewer::Viewer::Force );
   }
 }
@@ -1591,8 +1633,8 @@ void MainView::loadExternalReferences(bool load)
       const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
       Q_ASSERT( collection.isValid() );
 
-      KSharedConfigPtr config = KSharedConfig::openConfig( QLatin1String("kmail-mobilerc") );
-      KConfigGroup group( config, QString::fromLatin1("c%1" ).arg( collection.id() ) );
+      KSharedConfigPtr config = KSharedConfig::openConfig( "kmail-mobilerc" );
+      KConfigGroup group( config, QString( "c%1" ).arg( collection.id() ) );
       group.writeEntry( "htmlLoadExternalOverride", load );
     }
 
@@ -1613,37 +1655,51 @@ void MainView::folderChanged()
   bool htmlMailOverrideInAll = true;
   bool htmlLoadExternalOverrideInAll = true;
 
-  KSharedConfigPtr config = KSharedConfig::openConfig( QLatin1String("kmail-mobilerc") );
+  KSharedConfigPtr config = KSharedConfig::openConfig( "kmail-mobilerc" );
   Q_FOREACH( const QModelIndex &index, collectionSelectionModel->selectedRows() ) {
     Q_ASSERT( index.isValid() );
 
     const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
     Q_ASSERT( collection.isValid() );
 
-    KConfigGroup group( config, QString::fromLatin1( "c%1" ).arg( collection.id() ) );
+    KConfigGroup group( config, QString( "c%1" ).arg( collection.id() ) );
     if ( group.readEntry( "htmlMailOverride", false ) == false )
       htmlMailOverrideInAll = false;
 
     if ( group.readEntry( "htmlLoadExternalOverride", false ) == false )
       htmlLoadExternalOverrideInAll = false;
   }
-  actionCollection()->action( QLatin1String("prefer_html_to_plain") )->setChecked( htmlMailOverrideInAll );
-  actionCollection()->action( QLatin1String("prefer_html_to_plain_viewer") )->setChecked( htmlMailOverrideInAll );
+  actionCollection()->action( "prefer_html_to_plain" )->setChecked( htmlMailOverrideInAll );
+  actionCollection()->action( "prefer_html_to_plain_viewer" )->setChecked( htmlMailOverrideInAll );
   preferHTML( htmlMailOverrideInAll );
-  actionCollection()->action( QLatin1String("load_external_ref") )->setChecked( htmlLoadExternalOverrideInAll );
+  actionCollection()->action( "load_external_ref" )->setChecked( htmlLoadExternalOverrideInAll );
   loadExternalReferences( htmlLoadExternalOverrideInAll );
 
-  actionCollection()->action( QLatin1String("move_all_to_trash") )->setText( i18n( "Move Displayed Emails To Trash" ) );
+  actionCollection()->action( "move_all_to_trash" )->setText( i18n( "Move Displayed Emails To Trash" ) );
   if ( indexes.count() == 1 ) {
     const QModelIndex index = collectionSelectionModel->selection().indexes().first();
     const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
     Q_ASSERT( collection.isValid() );
 
     if ( CommonKernel->folderIsTrash( collection ) )
-      actionCollection()->action( QLatin1String("move_all_to_trash") )->setText( i18n( "Empty Trash" ) );
+      actionCollection()->action( "move_all_to_trash" )->setText( i18n( "Empty Trash" ) );
   }
 }
 
+void MainView::showExpireProperties()
+{
+  const QItemSelectionModel *collectionSelectionModel = regularSelectionModel();
+  if ( collectionSelectionModel->selection().indexes().isEmpty() )
+    return;
+
+  const QModelIndex index = collectionSelectionModel->selection().indexes().first();
+  const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
+  Q_ASSERT( collection.isValid() );
+
+  MailCommon::ExpiryPropertiesDialog *dlg = new MailCommon::ExpiryPropertiesDialog( this, collection );
+  dlg->show();
+}
+
 void MainView::moveToOrEmptyTrash()
 {
   const QItemSelectionModel *collectionSelectionModel = regularSelectionModel();
@@ -1664,6 +1720,24 @@ void MainView::moveToOrEmptyTrash()
   }
 }
 
+void MainView::createToDo()
+{
+  const Item item = currentItem();
+  if ( !item.isValid() )
+    return;
+
+  MailCommon::Util::createTodoFromMail( item );
+}
+
+void MainView::createEvent()
+{
+  const Item item = currentItem();
+  if ( !item.isValid() )
+    return;
+
+  MailCommon::Util::createEventFromMail( item );
+}
+
 void MainView::useFixedFont()
 {
   MessageViewer::MessageViewItem* item = messageViewerItem();
@@ -1921,3 +1995,4 @@ void MainView::messageListSettingsChanged( const MessageListSettings &settings )
 
 // #############################################################
 
+#include "mainview.moc"
