@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2015 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,23 +16,33 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef TEMPLATEPARSER_TEMPLATESTEXTEDIT_H
-#define TEMPLATEPARSER_TEMPLATESTEXTEDIT_H
-
+#ifndef TEMPLATESTEXTEDIT_H
+#define TEMPLATESTEXTEDIT_H
 #include "templateparser_export.h"
 
-#include "pimcommon/texteditor/richtexteditor/richtexteditorwidget.h"
+#include <KTextEdit>
+class QCompleter;
 
 namespace TemplateParser {
-class TEMPLATEPARSER_EXPORT TemplatesTextEdit : public PimCommon::RichTextEditorWidget
+class TEMPLATEPARSER_EXPORT TemplatesTextEdit : public KTextEdit
 {
-    Q_OBJECT
+  Q_OBJECT
 public:
-    explicit TemplatesTextEdit( QWidget *parent = 0 );
-    ~TemplatesTextEdit();
+  explicit TemplatesTextEdit( QWidget *parent );
+  virtual ~TemplatesTextEdit();
+
+
+protected slots:
+  void slotInsertCompletion( const QString& );
+  QString wordUnderCursor();
+protected:
+  void initCompleter();
+  void keyPressEvent(QKeyEvent* e);  
+private:
+  QCompleter *m_completer;
 };
 
 }
 
-#endif
+#endif /* TEMPLATESTEXTEDIT_H */
 
